/***************************************************************************

Pac-Man memory map (preliminary)

0000-3fff ROM
4000-43ff Video RAM
4400-47ff Color RAM
4c00-4fff RAM
8000-9fff ROM (Ms Pac-Man and Ponpoko only)
a000-bfff ROM (Ponpoko only)

memory mapped ports:

read:
5000      IN0
5040      IN1
5080      DSW 1
50c0	  DSW 2 (Ponpoko only)
see the input_ports definition below for details on the input bits

write:
4ff0-4fff 8 pairs of two bytes:
          the first byte contains the sprite image number (bits 2-7), Y flip (bit 0),
		  X flip (bit 1); the second byte the color
5000      interrupt enable
5001      sound enable
5002      ????
5003      flip screen
5004      1 player start lamp
5005      2 players start lamp
5006      coin lockout
5007      coin counter
5040-5044 sound voice 1 accumulator (nibbles) (used by the sound hardware only)
5045      sound voice 1 waveform (nibble)
5046-5049 sound voice 2 accumulator (nibbles) (used by the sound hardware only)
504a      sound voice 2 waveform (nibble)
504b-504e sound voice 3 accumulator (nibbles) (used by the sound hardware only)
504f      sound voice 3 waveform (nibble)
5050-5054 sound voice 1 frequency (nibbles)
5055      sound voice 1 volume (nibble)
5056-5059 sound voice 2 frequency (nibbles)
505a      sound voice 2 volume (nibble)
505b-505e sound voice 3 frequency (nibbles)
505f      sound voice 3 volume (nibble)
5060-506f Sprite coordinates, x/y pairs for 8 sprites
50c0      Watchdog reset

I/O ports:
OUT on port $0 sets the interrupt vector



Make Trax driver


Make Trax protection description:

Make Trax has a "Special" chip that it uses for copy protection.
The following chart shows when reads and writes may occur:

AAAAAAAA AAAAAAAA
11111100 00000000  <- address bits
54321098 76543210
xxx1xxxx 01xxxxxx - read data bits 4 and 7
xxx1xxxx 10xxxxxx - read data bits 6 and 7
xxx1xxxx 11xxxxxx - read data bits 0 through 5

xxx1xxxx 00xxx100 - write to Special
xxx1xxxx 00xxx101 - write to Special
xxx1xxxx 00xxx110 - write to Special
xxx1xxxx 00xxx111 - write to Special

In practical terms, it reads from Special when it reads from
location $5040-$50FF.  Note that these locations overlap our
inputs and Dip Switches.  Yuk.

I don't bother trapping the writes right now, because I don't
know how to interpret them.  However, comparing against Crush
Roller gives most of the values necessary on the reads.

Instead of always reading from $5040, $5080, and $50C0, the Make
Trax programmers chose to read from a wide variety of locations,
probably to make debugging easier.  To us, it means that for the most
part we can just assign a specific value to return for each address and
we'll be OK.  This falls apart for the following addresses:  $50C0, $508E,
$5090, and $5080.  These addresses should return multiple values.  The other
ugly thing happening is in the ROMs at $3AE5.  It keeps checking for
different values of $50C0 and $5080, and weird things happen if it gets
the wrong values.  The only way I've found around these is to patch the
ROMs using the same patches Crush Roller uses.  The only thing to watch
with this is that changing the ROMs will break the beginning checksum.
That's why we use the rom opcode decode function to do our patches.

Incidentally, there are extremely few differences between Crush Roller
and Make Trax.  About 98% of the differences appear to be either unused
bytes, the name of the game, or code related to the protection.  I've
only spotted two or three actual differences in the games, and they all
seem minor.

If anybody cares, here's a list of disassembled addresses for every
read and write to the Special chip (not all of the reads are
specifically for checking the Special bits, some are for checking
player inputs and Dip Switches):

Writes: $0084, $012F, $0178, $023C, $0C4C, $1426, $1802, $1817,
	$280C, $2C2E, $2E22, $3205, $3AB7, $3ACC, $3F3D, $3F40,
	$3F4E, $3F5E
Reads:  $01C8, $01D2, $0260, $030E, $040E, $0416, $046E, $0474,
	$0560, $0568, $05B0, $05B8, $096D, $0972, $0981, $0C27,
	$0C2C, $0F0A, $10B8, $10BE, $111F, $1127, $1156, $115E,
	$11E3, $11E8, $18B7, $18BC, $18CA, $1973, $197A, $1BE7,
	$1C06, $1C9F, $1CAA, $1D79, $213D, $2142, $2389, $238F,
	$2AAE, $2BF4, $2E0A, $39D5, $39DA, $3AE2, $3AEA, $3EE0,
	$3EE9, $3F07, $3F0D



Notes:

- The mystery items in Ali Baba don't work correctly because of protection

***************************************************************************/

#include "driver.h"
#include "vidhrdw/generic.h"

// Start Emu Plus
void fastpacman_init_machine(void);
int fastpacman_interrupt(void);
void plusfast_init_machine(void);
int plusfast_interrupt(void);
// End Emu Plus

int pacman_vh_start(void);
void pacman_vh_convert_color_prom(unsigned char *palette, unsigned short *colortable,const unsigned char *color_prom);
WRITE_HANDLER( pengo_flipscreen_w );
void pengo_vh_screenrefresh(struct osd_bitmap *bitmap,int full_refresh);

extern unsigned char *pengo_soundregs;
WRITE_HANDLER( pengo_sound_enable_w );
WRITE_HANDLER( pengo_sound_w );

extern void pacplus_decode(void);
extern void jumpshot_decode(void);
extern void shootbul_decode(void);

void theglob_init_machine(void);
READ_HANDLER( theglob_decrypt_rom );


static int speedcheat = 0;	/* a well known hack allows to make Pac Man run at four times */
					/* his usual speed. When we start the emulation, we check if the */
					/* hack can be applied, and set this flag accordingly. */


void pacman_init_machine(void)
{
	unsigned char *RAM = memory_region(REGION_CPU1);


	/* check if the loaded set of ROMs allows the Pac Man speed hack */
	if ((RAM[0x180b] == 0xbe && RAM[0x1ffd] == 0x00) ||
			(RAM[0x180b] == 0x01 && RAM[0x1ffd] == 0xbd))
		speedcheat = 1;
	else
		speedcheat = 0;
}

static int pacman_interrupt(void)
{
	unsigned char *RAM = memory_region(REGION_CPU1);

	/* speed up cheat */
	if (speedcheat)
	{
		if (readinputport(4) & 1)	/* check status of the fake dip switch */
		{
			/* activate the cheat */
			RAM[0x180b] = 0x01;
			RAM[0x1ffd] = 0xbd;
		}
		else
		{
			/* remove the cheat */
			RAM[0x180b] = 0xbe;
			RAM[0x1ffd] = 0x00;
		}
	}

	return interrupt();
}


static WRITE_HANDLER( pacman_leds_w )
{
	set_led_status(offset,data & 1);
}

static WRITE_HANDLER( pacman_coin_counter_w )
{
	coin_counter_w(offset,data & 1);
}

static WRITE_HANDLER( alibaba_sound_w )
{
	/* since the sound region in Ali Baba is not contiguous, translate the
	   offset into the 0-0x1f range */
 	if (offset < 0x10)
		pengo_sound_w(offset, data);
	else if (offset < 0x20)
		spriteram_2[offset - 0x10] = data;
	else
		pengo_sound_w(offset - 0x10, data);
}


static READ_HANDLER( alibaba_mystery_1_r )
{
	// The return value determines what the mystery item is.  Each bit corresponds
	// to a question mark

	return rand() & 0x0f;
}

static READ_HANDLER( alibaba_mystery_2_r )
{
	static int mystery = 0;

	// The single bit return value determines when the mystery is lit up.
	// This is certainly wrong

	mystery++;
	return (mystery >> 10) & 1;
}

// Start Emu Plus
/* PacMAME 23 Dec 2000*/
/*Zola Timer*/
static int timerthing = 0x00;
READ_HANDLER(zolatimer_r)
{
timerthing = timerthing + 0x01;
if (timerthing == 0xff) timerthing = 0x00;
return timerthing;
}
/*Zola Timer*/

static PORT_READ_START( zolapac_readport)
{ 0x00,0x00, zolatimer_r },
PORT_END
/* End PacMAME */
// End Emu Plus

static WRITE_HANDLER( pacman_coin_lockout_global_w )
{
	coin_lockout_global_w(~data & 0x01);
}


static MEMORY_READ_START( readmem )
	{ 0x0000, 0x3fff, MRA_ROM },
	{ 0x4000, 0x47ff, MRA_RAM },	/* video and color RAM */
	{ 0x4c00, 0x4fff, MRA_RAM },	/* including sprite codes at 4ff0-4fff */
	{ 0x5000, 0x503f, input_port_0_r },	/* IN0 */
	{ 0x5040, 0x507f, input_port_1_r },	/* IN1 */
	{ 0x5080, 0x50bf, input_port_2_r },	/* DSW1 */
	{ 0x50c0, 0x50ff, input_port_3_r },	/* DSW2 */
	{ 0x8000, 0xbfff, MRA_ROM },	/* Ms. Pac-Man / Ponpoko only */
MEMORY_END

static MEMORY_WRITE_START( writemem )
	{ 0x0000, 0x3fff, MWA_ROM },
	{ 0x4000, 0x43ff, videoram_w, &videoram, &videoram_size },
	{ 0x4400, 0x47ff, colorram_w, &colorram },
	{ 0x4c00, 0x4fef, MWA_RAM },
	{ 0x4ff0, 0x4fff, MWA_RAM, &spriteram, &spriteram_size },
	{ 0x5000, 0x5000, interrupt_enable_w },
	{ 0x5001, 0x5001, pengo_sound_enable_w },
	{ 0x5002, 0x5002, MWA_NOP },
	{ 0x5003, 0x5003, pengo_flipscreen_w },
 	{ 0x5004, 0x5005, pacman_leds_w },
// 	{ 0x5006, 0x5006, pacman_coin_lockout_global_w },	this breaks many games
 	{ 0x5007, 0x5007, pacman_coin_counter_w },
	{ 0x5040, 0x505f, pengo_sound_w, &pengo_soundregs },
	{ 0x5060, 0x506f, MWA_RAM, &spriteram_2 },
	{ 0x50c0, 0x50c0, watchdog_reset_w },
	{ 0x8000, 0xbfff, MWA_ROM },	/* Ms. Pac-Man / Ponpoko only */
	{ 0xc000, 0xc3ff, videoram_w }, /* mirror address for video ram, */
	{ 0xc400, 0xc7ef, colorram_w }, /* used to display HIGH SCORE and CREDITS */
	{ 0xffff, 0xffff, MWA_NOP },	/* Eyes writes to this location to simplify code */
MEMORY_END


static MEMORY_READ_START( alibaba_readmem )
	{ 0x0000, 0x3fff, MRA_ROM },
	{ 0x4000, 0x47ff, MRA_RAM },	/* video and color RAM */
	{ 0x4c00, 0x4fff, MRA_RAM },	/* including sprite codes at 4ef0-4eff */
	{ 0x5000, 0x503f, input_port_0_r },	/* IN0 */
	{ 0x5040, 0x507f, input_port_1_r },	/* IN1 */
	{ 0x5080, 0x50bf, input_port_2_r },	/* DSW1 */
	{ 0x50c0, 0x50c0, alibaba_mystery_1_r },
	{ 0x50c1, 0x50c1, alibaba_mystery_2_r },
	{ 0x8000, 0x8fff, MRA_ROM },
	{ 0x9000, 0x93ff, MRA_RAM },
	{ 0xa000, 0xa7ff, MRA_ROM },
MEMORY_END

static MEMORY_WRITE_START( alibaba_writemem )
	{ 0x0000, 0x3fff, MWA_ROM },
	{ 0x4000, 0x43ff, videoram_w, &videoram, &videoram_size },
	{ 0x4400, 0x47ff, colorram_w, &colorram },
	{ 0x4ef0, 0x4eff, MWA_RAM, &spriteram, &spriteram_size },
	{ 0x4c00, 0x4fff, MWA_RAM },
	{ 0x5000, 0x5000, watchdog_reset_w },
 	{ 0x5004, 0x5005, pacman_leds_w },
 	{ 0x5006, 0x5006, pacman_coin_lockout_global_w },
 	{ 0x5007, 0x5007, pacman_coin_counter_w },
	{ 0x5040, 0x506f, alibaba_sound_w, &pengo_soundregs },  /* the sound region is not contiguous */
	{ 0x5060, 0x506f, MWA_RAM, &spriteram_2 }, /* actually at 5050-505f, here to point to free RAM */
	{ 0x50c0, 0x50c0, pengo_sound_enable_w },
	{ 0x50c1, 0x50c1, pengo_flipscreen_w },
	{ 0x50c2, 0x50c2, interrupt_enable_w },
	{ 0x8000, 0x8fff, MWA_ROM },
	{ 0x9000, 0x93ff, MWA_RAM },
	{ 0xa000, 0xa7ff, MWA_ROM },
	{ 0xc000, 0xc3ff, videoram_w }, /* mirror address for video ram, */
	{ 0xc400, 0xc7ef, colorram_w }, /* used to display HIGH SCORE and CREDITS */
MEMORY_END



static PORT_WRITE_START( writeport )
	{ 0x00, 0x00, interrupt_vector_w },	/* Pac-Man only */
PORT_END


static PORT_WRITE_START( vanvan_writeport )
	{ 0x01, 0x01, SN76496_0_w },
	{ 0x02, 0x02, SN76496_1_w },
PORT_END

static PORT_WRITE_START( dremshpr_writeport )
	{ 0x06, 0x06, AY8910_write_port_0_w },
	{ 0x07, 0x07, AY8910_control_port_0_w },
PORT_END


static MEMORY_READ_START( theglob_readmem )
	{ 0x0000, 0x3fff, MRA_BANK1 },
	{ 0x4000, 0x47ff, MRA_RAM },	/* video and color RAM */
	{ 0x4c00, 0x4fff, MRA_RAM },	/* including sprite codes at 4ff0-4fff */
	{ 0x5000, 0x503f, input_port_0_r },	/* IN0 */
	{ 0x5040, 0x507f, input_port_1_r },	/* IN1 */
	{ 0x5080, 0x50bf, input_port_2_r },	/* DSW1 */
	{ 0x50c0, 0x50ff, input_port_3_r },	/* DSW2 */
MEMORY_END

static PORT_READ_START( theglob_readport )
	{ 0x00, 0xff, theglob_decrypt_rom },	/* Switch protection logic */
PORT_END


INPUT_PORTS_START( pacman )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_BITX(    0x10, 0x10, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Rack Test", KEYCODE_F1, IP_JOY_NONE )
	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_DIPNAME(0x80, 0x80, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(   0x80, DEF_STR( Upright ) )
	PORT_DIPSETTING(   0x00, DEF_STR( Cocktail ) )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x08, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x00, "1" )
	PORT_DIPSETTING(    0x04, "2" )
	PORT_DIPSETTING(    0x08, "3" )
	PORT_DIPSETTING(    0x0c, "5" )
	PORT_DIPNAME( 0x30, 0x00, DEF_STR( Bonus_Life ) )
	PORT_DIPSETTING(    0x00, "10000" )
	PORT_DIPSETTING(    0x10, "15000" )
	PORT_DIPSETTING(    0x20, "20000" )
	PORT_DIPSETTING(    0x30, "None" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Difficulty ) )
	PORT_DIPSETTING(    0x40, "Normal" )
	PORT_DIPSETTING(    0x00, "Hard" )
	PORT_DIPNAME( 0x80, 0x80, "Ghost Names" )
	PORT_DIPSETTING(    0x80, "Normal" )
	PORT_DIPSETTING(    0x00, "Alternate" )

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )

	PORT_START	/* FAKE */
	/* This fake input port is used to get the status of the fire button */
	/* and activate the speedup cheat if it is. */
	PORT_BITX(    0x01, 0x00, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Speedup Cheat", KEYCODE_LCONTROL, JOYCODE_1_BUTTON1 )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
INPUT_PORTS_END

/* Ms. Pac-Man input ports are identical to Pac-Man, the only difference is */
/* the missing Ghost Names dip switch. */
INPUT_PORTS_START( mspacman )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_BITX(    0x10, 0x10, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Rack Test", KEYCODE_F1, IP_JOY_NONE )
	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x08, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x00, "1" )
	PORT_DIPSETTING(    0x04, "2" )
	PORT_DIPSETTING(    0x08, "3" )
	PORT_DIPSETTING(    0x0c, "5" )
	PORT_DIPNAME( 0x30, 0x00, DEF_STR( Bonus_Life ) )
	PORT_DIPSETTING(    0x00, "10000" )
	PORT_DIPSETTING(    0x10, "15000" )
	PORT_DIPSETTING(    0x20, "20000" )
	PORT_DIPSETTING(    0x30, "None" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Difficulty ) )
	PORT_DIPSETTING(    0x40, "Normal" )
	PORT_DIPSETTING(    0x00, "Hard" )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )

	PORT_START	/* FAKE */
	/* This fake input port is used to get the status of the fire button */
	/* and activate the speedup cheat if it is. */
	PORT_BITX(    0x01, 0x00, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Speedup Cheat", KEYCODE_LCONTROL, JOYCODE_1_BUTTON1 )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
INPUT_PORTS_END

INPUT_PORTS_START( maketrax )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x10, DEF_STR( Cocktail ) )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_UNUSED )  /* Protection */
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )  /* Protection */

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x00, "3" )
	PORT_DIPSETTING(    0x04, "4" )
	PORT_DIPSETTING(    0x08, "5" )
	PORT_DIPSETTING(    0x0c, "6" )
	PORT_DIPNAME( 0x10, 0x10, "First Pattern" )
	PORT_DIPSETTING(    0x10, "Easy" )
	PORT_DIPSETTING(    0x00, "Hard" )
	PORT_DIPNAME( 0x20, 0x20, "Teleport Holes" )
	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
 	PORT_BIT( 0xc0, IP_ACTIVE_HIGH, IPT_UNUSED )  /* Protection */

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END

INPUT_PORTS_START( mbrush )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x10, DEF_STR( Cocktail ) )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_UNUSED )  /* Protection in Make Trax */
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )  /* Protection in Make Trax */

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x08, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x00, "1" )
	PORT_DIPSETTING(    0x04, "2" )
	PORT_DIPSETTING(    0x08, "3" )
	PORT_DIPSETTING(    0x0c, "4" )
	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_BIT( 0xc0, IP_ACTIVE_HIGH, IPT_UNUSED )  /* Protection in Make Trax */

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END

INPUT_PORTS_START( paintrlr )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x10, DEF_STR( Cocktail ) )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_UNUSED )  /* Protection in Make Trax */
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )  /* Protection in Make Trax */

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x00, "3" )
	PORT_DIPSETTING(    0x04, "4" )
	PORT_DIPSETTING(    0x08, "5" )
	PORT_DIPSETTING(    0x0c, "6" )
	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_BIT( 0xc0, IP_ACTIVE_HIGH, IPT_UNUSED )  /* Protection in Make Trax */

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END

INPUT_PORTS_START( ponpoko )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP    | IPF_8WAY )
	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT  | IPF_8WAY )
	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT | IPF_8WAY )
	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN  | IPF_8WAY )
	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )

	/* The 2nd player controls are used even in upright mode */
	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_HIGH, IPT_JOYSTICK_UP    | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x02, IP_ACTIVE_HIGH, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x04, IP_ACTIVE_HIGH, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x08, IP_ACTIVE_HIGH, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x10, IP_ACTIVE_HIGH, IPT_BUTTON1 | IPF_PLAYER2 )
	PORT_BIT( 0x20, IP_ACTIVE_HIGH, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_HIGH, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_HIGH, IPT_UNUSED )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Bonus_Life ) )
	PORT_DIPSETTING(    0x01, "10000" )
	PORT_DIPSETTING(    0x02, "30000" )
	PORT_DIPSETTING(    0x03, "50000" )
	PORT_DIPSETTING(    0x00, "None" )
	PORT_DIPNAME( 0x0c, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, "0" )
	PORT_DIPSETTING(    0x04, "1" )
	PORT_DIPSETTING(    0x08, "2" )
	PORT_DIPSETTING(    0x0c, "3" )
	PORT_DIPNAME( 0x30, 0x20, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x00, "2" )
	PORT_DIPSETTING(    0x10, "3" )
	PORT_DIPSETTING(    0x20, "4" )
	PORT_DIPSETTING(    0x30, "5" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x40, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )

	PORT_START	/* DSW 2 */
	PORT_DIPNAME( 0x0f, 0x01, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x04, "A 3/1 B 3/1" )
	PORT_DIPSETTING(    0x0e, "A 3/1 B 1/2" )
	PORT_DIPSETTING(    0x0f, "A 3/1 B 1/4" )
	PORT_DIPSETTING(    0x02, "A 2/1 B 2/1" )
	PORT_DIPSETTING(    0x0d, "A 2/1 B 1/1" )
	PORT_DIPSETTING(    0x07, "A 2/1 B 1/3" )
	PORT_DIPSETTING(    0x0b, "A 2/1 B 1/5" )
	PORT_DIPSETTING(    0x0c, "A 2/1 B 1/6" )
	PORT_DIPSETTING(    0x01, "A 1/1 B 1/1" )
	PORT_DIPSETTING(    0x06, "A 1/1 B 4/5" )
	PORT_DIPSETTING(    0x05, "A 1/1 B 2/3" )
	PORT_DIPSETTING(    0x0a, "A 1/1 B 1/3" )
	PORT_DIPSETTING(    0x08, "A 1/1 B 1/5" )
	PORT_DIPSETTING(    0x09, "A 1/1 B 1/6" )
	PORT_DIPSETTING(    0x03, "A 1/2 B 1/2" )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )  /* Most likely unused */
	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ) )  /* Most likely unused */
	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Demo_Sounds ) )
	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )  /* Most likely unused */
	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
INPUT_PORTS_END

INPUT_PORTS_START( eyes )
	PORT_START  /* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_TILT )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x08, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x0c, "2" )
	PORT_DIPSETTING(    0x08, "3" )
	PORT_DIPSETTING(    0x04, "4" )
	PORT_DIPSETTING(    0x00, "5" )
	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Bonus_Life ) )
	PORT_DIPSETTING(    0x30, "50000" )
	PORT_DIPSETTING(    0x20, "75000" )
	PORT_DIPSETTING(    0x10, "100000" )
	PORT_DIPSETTING(    0x00, "125000" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x40, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )  /* Not accessed */
	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END

INPUT_PORTS_START( mrtnt )
	PORT_START  /* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_TILT )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x08, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x0c, "2" )
	PORT_DIPSETTING(    0x08, "3" )
	PORT_DIPSETTING(    0x04, "4" )
	PORT_DIPSETTING(    0x00, "5" )
	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Bonus_Life ) )
	PORT_DIPSETTING(    0x30, "75000" )
	PORT_DIPSETTING(    0x20, "100000" )
	PORT_DIPSETTING(    0x10, "125000" )
	PORT_DIPSETTING(    0x00, "150000" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x40, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END

INPUT_PORTS_START( lizwiz )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY )
	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_TILT )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER2 )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x08, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x0c, "2" )
	PORT_DIPSETTING(    0x08, "3" )
	PORT_DIPSETTING(    0x04, "4" )
	PORT_DIPSETTING(    0x00, "5" )
	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Bonus_Life ) )
	PORT_DIPSETTING(    0x30, "75000" )
	PORT_DIPSETTING(    0x20, "100000" )
	PORT_DIPSETTING(    0x10, "125000" )
	PORT_DIPSETTING(    0x00, "150000" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Difficulty ) )
	PORT_DIPSETTING(    0x40, "Normal" )
	PORT_DIPSETTING(    0x00, "Hard" )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END

INPUT_PORTS_START( theglob )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_UNKNOWN )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_BUTTON2 | IPF_COCKTAIL )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON2 )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x03, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x03, "3" )
	PORT_DIPSETTING(    0x02, "4" )
	PORT_DIPSETTING(    0x01, "5" )
	PORT_DIPSETTING(    0x00, "6" )
	PORT_DIPNAME( 0x1c, 0x1c, DEF_STR( Difficulty ) )
	PORT_DIPSETTING(    0x1c, "Easiest" )
	PORT_DIPSETTING(    0x18, "Very Easy" )
	PORT_DIPSETTING(    0x14, "Easy" )
	PORT_DIPSETTING(    0x10, "Normal" )
	PORT_DIPSETTING(    0x0c, "Difficult" )
	PORT_DIPSETTING(    0x08, "Very Difficult" )
	PORT_DIPSETTING(    0x04, "Very Hard" )
	PORT_DIPSETTING(    0x00, "Hardest" )
	PORT_DIPNAME( 0x20, 0x00, DEF_STR( Demo_Sounds ) )
	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END

INPUT_PORTS_START( vanvan )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )

	/* The 2nd player controls are used even in upright mode */
	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x01, DEF_STR( Cocktail ) )
	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Flip_Screen ) )
	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x04, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x30, "3" )
	PORT_DIPSETTING(    0x20, "4" )
	PORT_DIPSETTING(    0x10, "5" )
	PORT_DIPSETTING(    0x00, "6" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Coin_A ) )
	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x40, DEF_STR( 1C_1C ) )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Coin_B ) )
	PORT_DIPSETTING(    0x80, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( 1C_3C ) )

	PORT_START	/* DSW 2 */
	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
	PORT_BITX(    0x02, 0x00, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Invulnerability", KEYCODE_F1, IP_JOY_NONE )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
	PORT_DIPNAME( 0x08, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
	PORT_DIPNAME( 0x20, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x20, DEF_STR( On ) )
	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
INPUT_PORTS_END

INPUT_PORTS_START( vanvans )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )

	/* The 2nd player controls are used even in upright mode */
	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x01, DEF_STR( Cocktail ) )
	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Flip_Screen ) )
	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x04, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x30, "3" )
	PORT_DIPSETTING(    0x20, "4" )
	PORT_DIPSETTING(    0x10, "5" )
	PORT_DIPSETTING(    0x00, "6" )
	PORT_DIPNAME( 0xc0, 0xc0, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x80, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x40, DEF_STR( 1C_3C ) )

	PORT_START	/* DSW 2 */
	PORT_DIPNAME( 0x01, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
	PORT_BITX(    0x02, 0x00, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Invulnerability", KEYCODE_F1, IP_JOY_NONE )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x02, DEF_STR( On ) )
	PORT_DIPNAME( 0x04, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x04, DEF_STR( On ) )
	PORT_DIPNAME( 0x08, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
	PORT_DIPNAME( 0x10, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x10, DEF_STR( On ) )
	PORT_DIPNAME( 0x20, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x20, DEF_STR( On ) )
	PORT_DIPNAME( 0x40, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x40, DEF_STR( On ) )
	PORT_DIPNAME( 0x80, 0x00, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x80, DEF_STR( On ) )
INPUT_PORTS_END

INPUT_PORTS_START( dremshpr )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_UNKNOWN )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNKNOWN )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x01, 0x01, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x01, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )
	PORT_DIPNAME( 0x02, 0x02, DEF_STR( Flip_Screen ) )
	PORT_DIPSETTING(    0x02, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x0c, 0x0c, DEF_STR( Bonus_Life ) )
	PORT_DIPSETTING(    0x08, "30000" )
	PORT_DIPSETTING(    0x04, "50000" )
	PORT_DIPSETTING(    0x00, "70000" )
	PORT_DIPSETTING(    0x0c, "None" )
	PORT_DIPNAME( 0x30, 0x30, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x30, "3" )
	PORT_DIPSETTING(    0x20, "4" )
	PORT_DIPSETTING(    0x10, "5" )
	PORT_DIPSETTING(    0x00, "6" )
	PORT_DIPNAME( 0xc0, 0xc0, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x00, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0xc0, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x80, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x40, DEF_STR( 1C_3C ) )

	PORT_START	/* DSW 2 */
  //PORT_BITX(    0x01, 0x00, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Invulnerability", IP_KEY_NONE, IP_JOY_NONE )
  //PORT_DIPSETTING(    0x00, DEF_STR( Off ) )		/* turning this on crashes puts the */
  //PORT_DIPSETTING(    0x01, DEF_STR( On ) )       /* emulated machine in an infinite loop once in a while */
//	PORT_DIPNAME( 0xff, 0x00, DEF_STR( Unused ) )
	PORT_BIT( 0xfe, IP_ACTIVE_LOW, IPT_UNUSED )
INPUT_PORTS_END

INPUT_PORTS_START( alibaba )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_BITX(0x10, 0x10, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Rack Test", KEYCODE_F1, IP_JOY_NONE )
	PORT_DIPSETTING(0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(0x00, DEF_STR( On ) )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN2 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x10, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_COCKTAIL )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x08, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x00, "1" )
	PORT_DIPSETTING(    0x04, "2" )
	PORT_DIPSETTING(    0x08, "3" )
	PORT_DIPSETTING(    0x0c, "5" )
	PORT_DIPNAME( 0x30, 0x00, DEF_STR( Bonus_Life ) )
	PORT_DIPSETTING(    0x00, "10000" )
	PORT_DIPSETTING(    0x10, "15000" )
	PORT_DIPSETTING(    0x20, "20000" )
	PORT_DIPSETTING(    0x30, "None" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Difficulty ) )
	PORT_DIPSETTING(    0x40, "Normal" )
	PORT_DIPSETTING(    0x00, "Hard" )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Off) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
INPUT_PORTS_END

INPUT_PORTS_START( jumpshot )
	PORT_START /* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY )
	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_SERVICE1 )

	PORT_START /* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_8WAY | IPF_PLAYER2 )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_8WAY | IPF_PLAYER2 )
	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_BUTTON1 | IPF_PLAYER2  )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )

	PORT_START /* DSW 1 */
	PORT_DIPNAME( 0x03, 0x01, "Time"  )
//	PORT_DIPSETTING(    0x00,  "2 Minutes"  )
	PORT_DIPSETTING(    0x02,  "2 Minutes" )
	PORT_DIPSETTING(    0x03,  "3 Minutes" )
	PORT_DIPSETTING(    0x01,  "4 Minutes"  )
	PORT_DIPNAME( 0x04, 0x04, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x04, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x08, 0x08, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x08, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Free_Play ) )
	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x20, 0x00, "2 Players Game" )
	PORT_DIPSETTING(    0x20, "1 Credit" )
	PORT_DIPSETTING(    0x00, "2 Credits" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Off) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )

	PORT_START /* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END

INPUT_PORTS_START( shootbul )
	PORT_START /* IN0 */
	PORT_ANALOG( 0x0f, 0x0f, IPT_TRACKBALL_X , 50, 25, 0, 0)
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN3 )

	PORT_START /* IN1 */
	PORT_ANALOG( 0x0f, 0x0f, IPT_TRACKBALL_Y | IPF_REVERSE, 50, 25, 0, 0)
	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_BUTTON1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START1 )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )

	PORT_START /* DSW 1 */
	PORT_DIPNAME( 0x07, 0x07, "Time"  )
	PORT_DIPSETTING(    0x01, "Short")
	PORT_DIPSETTING(    0x07, "Average" )
	PORT_DIPSETTING(    0x03, "Long" )
	PORT_DIPSETTING(    0x05, "Longer" )
	PORT_DIPSETTING(    0x06, "Longest" )
	PORT_DIPNAME( 0x08, 0x08, "Title Page Sounds"  )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x08, DEF_STR( On ) )
	PORT_DIPNAME( 0x10, 0x10, DEF_STR( Unknown ) )
	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x20, 0x20, DEF_STR( Unknown ))
	PORT_DIPSETTING(    0x20, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Unknown ))
	PORT_DIPSETTING(    0x40, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )

	PORT_START /* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )
INPUT_PORTS_END

// Start Emu Plus
/*PacMAME Games 23 Dec 2000*/
INPUT_PORTS_START( zolapac )
	PORT_START	/* IN0 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY )
	PORT_BITX(    0x10, 0x10, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Rack Test", KEYCODE_F1, IP_JOY_NONE )
	PORT_DIPSETTING(    0x10, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x00, DEF_STR( On ) )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_COIN1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_COIN2 )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_COIN3 )

	PORT_START	/* IN1 */
	PORT_BIT( 0x01, IP_ACTIVE_LOW, IPT_JOYSTICK_UP    | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x02, IP_ACTIVE_LOW, IPT_JOYSTICK_LEFT  | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x04, IP_ACTIVE_LOW, IPT_JOYSTICK_RIGHT | IPF_4WAY | IPF_COCKTAIL )
	PORT_BIT( 0x08, IP_ACTIVE_LOW, IPT_JOYSTICK_DOWN  | IPF_4WAY | IPF_COCKTAIL )
	PORT_SERVICE( 0x10, IP_ACTIVE_LOW )
	PORT_BIT( 0x20, IP_ACTIVE_LOW, IPT_START1 )
	PORT_BIT( 0x40, IP_ACTIVE_LOW, IPT_START2 )
	PORT_DIPNAME( 0x80, 0x80, DEF_STR( Cabinet ) )
	PORT_DIPSETTING(    0x80, DEF_STR( Upright ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Cocktail ) )

	PORT_START	/* DSW 1 */
	PORT_DIPNAME( 0x03, 0x01, DEF_STR( Coinage ) )
	PORT_DIPSETTING(    0x03, DEF_STR( 2C_1C ) )
	PORT_DIPSETTING(    0x01, DEF_STR( 1C_1C ) )
	PORT_DIPSETTING(    0x02, DEF_STR( 1C_2C ) )
	PORT_DIPSETTING(    0x00, DEF_STR( Free_Play ) )
	PORT_DIPNAME( 0x0c, 0x08, DEF_STR( Lives ) )
	PORT_DIPSETTING(    0x00, "1" )
	PORT_DIPSETTING(    0x04, "2" )
	PORT_DIPSETTING(    0x08, "3" )
	PORT_DIPSETTING(    0x0c, "5" )
	PORT_DIPNAME( 0x30, 0x00, DEF_STR( Bonus_Life ) )
	PORT_DIPSETTING(    0x00, "10000" )
	PORT_DIPSETTING(    0x10, "15000" )
	PORT_DIPSETTING(    0x20, "20000" )
	PORT_DIPSETTING(    0x30, "None" )
	PORT_DIPNAME( 0x40, 0x40, DEF_STR( Difficulty ) )
	PORT_DIPSETTING(    0x40, "Normal" )
	PORT_DIPSETTING(    0x00, "Hard" )
	PORT_BIT( 0x80, IP_ACTIVE_LOW, IPT_UNUSED )

	PORT_START	/* DSW 2 */
	PORT_BIT( 0xff, IP_ACTIVE_HIGH, IPT_UNUSED )

	PORT_START	/* FAKE */
	/* This fake input port is used to get the status of the fire button */
	/* and activate the speedup cheat if it is. */
	PORT_BITX(    0x01, 0x00, IPT_DIPSWITCH_NAME | IPF_CHEAT, "Speedup Cheat", KEYCODE_LCONTROL, JOYCODE_1_BUTTON1 )
	PORT_DIPSETTING(    0x00, DEF_STR( Off ) )
	PORT_DIPSETTING(    0x01, DEF_STR( On ) )
INPUT_PORTS_END
/*End PacMAME*/
// End Emu Plus

static struct GfxLayout tilelayout =
{
	8,8,	/* 8*8 characters */
    256,    /* 256 characters */
    2,  /* 2 bits per pixel */
    { 0, 4 },   /* the two bitplanes for 4 pixels are packed into one byte */
    { 8*8+0, 8*8+1, 8*8+2, 8*8+3, 0, 1, 2, 3 }, /* bits are packed in groups of four */
    { 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8 },
    16*8    /* every char takes 16 bytes */
};


static struct GfxLayout spritelayout =
{
	16,16,	/* 16*16 sprites */
	64,	/* 64 sprites */
	2,	/* 2 bits per pixel */
	{ 0, 4 },	/* the two bitplanes for 4 pixels are packed into one byte */
	{ 8*8, 8*8+1, 8*8+2, 8*8+3, 16*8+0, 16*8+1, 16*8+2, 16*8+3,
			24*8+0, 24*8+1, 24*8+2, 24*8+3, 0, 1, 2, 3 },
	{ 0*8, 1*8, 2*8, 3*8, 4*8, 5*8, 6*8, 7*8,
			32*8, 33*8, 34*8, 35*8, 36*8, 37*8, 38*8, 39*8 },
	64*8	/* every sprite takes 64 bytes */
};


static struct GfxDecodeInfo gfxdecodeinfo[] =
{
	{ REGION_GFX1, 0, &tilelayout,   0, 32 },
	{ REGION_GFX2, 0, &spritelayout, 0, 32 },
	{ -1 } /* end of array */
};


static struct namco_interface namco_interface =
{
	3072000/32,	/* sample rate */
	3,			/* number of voices */
	100,		/* playback volume */
	REGION_SOUND1	/* memory region */
};

static struct SN76496interface sn76496_interface =
{
	2,
	{ 1789750, 1789750 },	/* 1.78975 MHz ? */
	{ 75, 75 }
};

static struct AY8910interface dremshpr_ay8910_interface =
{
	1,	/* 1 chip */
	14318000/8,	/* 1.78975 MHz ??? */
	{ 50 },
	{ 0 },
	{ 0 },
	{ 0 },
	{ 0 }
};


static const struct MachineDriver machine_driver_pacman =
{
	/* basic machine hardware */
	{
		{
			CPU_Z80,
			18432000/6,	/* 3.072 MHz */
			readmem,writemem,0,writeport,
			pacman_interrupt,1
		}
	},
	60.606060, 2500,	/* frames per second, vblank duration */
	1,	/* single CPU, no need for interleaving */
	pacman_init_machine,

	/* video hardware */
	36*8, 28*8, { 0*8, 36*8-1, 0*8, 28*8-1 },
	gfxdecodeinfo,
	16, 4*32,
	pacman_vh_convert_color_prom,

	VIDEO_TYPE_RASTER,
	0,
	pacman_vh_start,
	generic_vh_stop,
	pengo_vh_screenrefresh,

	/* sound hardware */
	0,0,0,0,
	{
		{
			SOUND_NAMCO,
			&namco_interface
		}
	}
};

static const struct MachineDriver machine_driver_theglob =
{
	/* basic machine hardware */
	{
		{
			CPU_Z80,
			18432000/6,	/* 3.072 MHz */
			theglob_readmem,writemem,theglob_readport,writeport,
			pacman_interrupt,1
		}
	},
	60.606060, 2500,	/* frames per second, vblank duration */
	1,	/* single CPU, no need for interleaving */
	theglob_init_machine,

	/* video hardware */
	36*8, 28*8, { 0*8, 36*8-1, 0*8, 28*8-1 },
	gfxdecodeinfo,
	16, 4*32,
	pacman_vh_convert_color_prom,

	VIDEO_TYPE_RASTER,
	0,
	pacman_vh_start,
	generic_vh_stop,
	pengo_vh_screenrefresh,

	/* sound hardware */
	0,0,0,0,
	{
		{
			SOUND_NAMCO,
			&namco_interface
		}
	}
};

static const struct MachineDriver machine_driver_vanvan =
{
	/* basic machine hardware */
	{
		{
			CPU_Z80,
			18432000/6,	/* 3.072 MHz */
			readmem,writemem,0,vanvan_writeport,
			nmi_interrupt,1
		}
	},
	60.606060, 2500,	/* frames per second, vblank duration */
	1,	/* single CPU, no need for interleaving */
	0,

	/* video hardware */
	36*8, 28*8, { 0*8, 36*8-1, 0*8, 28*8-1 },
	gfxdecodeinfo,
	16, 4*32,
	pacman_vh_convert_color_prom,

	VIDEO_TYPE_RASTER,
	0,
	pacman_vh_start,
	generic_vh_stop,
	pengo_vh_screenrefresh,

	/* sound hardware */
	0,0,0,0,
	{
		{
			SOUND_SN76496,
			&sn76496_interface
		}
	}
};

static const struct MachineDriver machine_driver_dremshpr =
{
	/* basic machine hardware */
	{
		{
			CPU_Z80,
			18432000/6,	/* 3.072 MHz */
			readmem,writemem,0,dremshpr_writeport,
			nmi_interrupt,1
		}
	},
	60.606060, 2500,	/* frames per second, vblank duration */
	1,	/* single CPU, no need for interleaving */
	0,

	/* video hardware */
	36*8, 28*8, { 0*8, 36*8-1, 0*8, 28*8-1 },
	gfxdecodeinfo,
	16, 4*32,
	pacman_vh_convert_color_prom,

	VIDEO_TYPE_RASTER,
	0,
	pacman_vh_start,
	generic_vh_stop,
	pengo_vh_screenrefresh,

	/* sound hardware */
	0,0,0,0,
	{
		{
			SOUND_AY8910,
			&dremshpr_ay8910_interface
		}
	}
};

static const struct MachineDriver machine_driver_alibaba =
{
	/* basic machine hardware */
	{
		{
			CPU_Z80,
			18432000/6,	/* 3.072 MHz */
			alibaba_readmem,alibaba_writemem,0,0,
			interrupt,1
		}
	},
	60.606060, 2500,	/* frames per second, vblank duration */
	1,	/* single CPU, no need for interleaving */
	0,

	/* video hardware */
	36*8, 28*8, { 0*8, 36*8-1, 0*8, 28*8-1 },
	gfxdecodeinfo,
	16, 4*32,
	pacman_vh_convert_color_prom,

	VIDEO_TYPE_RASTER,
	0,
	pacman_vh_start,
	generic_vh_stop,
	pengo_vh_screenrefresh,

	/* sound hardware */
	0,0,0,0,
	{
		{
			SOUND_NAMCO,
			&namco_interface
		}
	}
};

// Start Emu Plus
/*PacMAME*/
static struct MachineDriver machine_driver_zolapac =
{
	/* basic machine hardware */
	{
		{
			CPU_Z80,
			18432000/6,	/* 3.072 Mhz */
			readmem,writemem,zolapac_readport,writeport,
			pacman_interrupt,1
		}
	},
	60.606060, 2500,	/* frames per second, vblank duration */
	1,	/* single CPU, no need for interleaving */
	pacman_init_machine,

	/* video hardware */
	36*8, 28*8, { 0*8, 36*8-1, 0*8, 28*8-1 },
	gfxdecodeinfo,
	16, 4*32,
	pacman_vh_convert_color_prom,

	VIDEO_TYPE_RASTER | VIDEO_SUPPORTS_DIRTY,
	0,
	pacman_vh_start,
	generic_vh_stop,
	pengo_vh_screenrefresh,

	/* sound hardware */
	0,0,0,0,
	{
		{
			SOUND_NAMCO,
			&namco_interface
		}
	}
};

static struct MachineDriver machine_driver_fastpac =
{
	/* basic machine hardware */
	{
		{
			CPU_Z80,
			18432000/6,	/* 3.072 Mhz */
			readmem,writemem,0,writeport,
			fastpacman_interrupt,1
		}
	},
	60.606060, 2500,	/* frames per second, vblank duration */
	1,	/* single CPU, no need for interleaving */
	fastpacman_init_machine,

	/* video hardware */
	36*8, 28*8, { 0*8, 36*8-1, 0*8, 28*8-1 },
	gfxdecodeinfo,
	16, 4*32,
	pacman_vh_convert_color_prom,

	VIDEO_TYPE_RASTER | VIDEO_SUPPORTS_DIRTY,
	0,
	pacman_vh_start,
	generic_vh_stop,
	pengo_vh_screenrefresh,

	/* sound hardware */
	0,0,0,0,
	{
		{
			SOUND_NAMCO,
			&namco_interface
		}
	}
};

static struct MachineDriver machine_driver_plusfast =
{
	/* basic machine hardware */
	{
		{
			CPU_Z80,
			18432000/6,	/* 3.072 Mhz */
			readmem,writemem,0,writeport,
			plusfast_interrupt,1
		}
	},
	60.606060, 2500,	/* frames per second, vblank duration */
	1,	/* single CPU, no need for interleaving */
	plusfast_init_machine,

	/* video hardware */
	36*8, 28*8, { 0*8, 36*8-1, 0*8, 28*8-1 },
	gfxdecodeinfo,
	16, 4*32,
	pacman_vh_convert_color_prom,

	VIDEO_TYPE_RASTER | VIDEO_SUPPORTS_DIRTY,
	0,
	pacman_vh_start,
	generic_vh_stop,
	pengo_vh_screenrefresh,

	/* sound hardware */
	0,0,0,0,
	{
		{
			SOUND_NAMCO,
			&namco_interface
		}
	}
};
/* End PacMAME */
//End Emu Plus

/***************************************************************************

  Game driver(s)

***************************************************************************/

ROM_START( pacman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "namcopac.6e",  0x0000, 0x1000, 0xfee263b3 )
	ROM_LOAD( "namcopac.6f",  0x1000, 0x1000, 0x39d1fc83 )
	ROM_LOAD( "namcopac.6h",  0x2000, 0x1000, 0x02083b03 )
	ROM_LOAD( "namcopac.6j",  0x3000, 0x1000, 0x7a36fe55 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( npacmod )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "namcopac.6e",  0x0000, 0x1000, 0xfee263b3 )
	ROM_LOAD( "namcopac.6f",  0x1000, 0x1000, 0x39d1fc83 )
	ROM_LOAD( "namcopac.6h",  0x2000, 0x1000, 0x02083b03 )
	ROM_LOAD( "npacmod.6j",   0x3000, 0x1000, 0x7d98d5f5 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( pacmanjp )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "prg7",         0x3000, 0x0800, 0xb6289b26 )
	ROM_LOAD( "prg8",         0x3800, 0x0800, 0x17a88c13 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "chg1",         0x0000, 0x0800, 0x2066a0b7 )
	ROM_LOAD( "chg2",         0x0800, 0x0800, 0x3591b89d )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( pacmanm )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( pacmod )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "pacmanh.6e",   0x0000, 0x1000, 0x3b2ec270 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacmanh.6h",   0x2000, 0x1000, 0x18811780 )
	ROM_LOAD( "pacmanh.6j",   0x3000, 0x1000, 0x5c96a733 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacmanh.5e",   0x0000, 0x1000, 0x299fb17a )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( hangly )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "hangly.6e",    0x0000, 0x1000, 0x5fe8610a )
	ROM_LOAD( "hangly.6f",    0x1000, 0x1000, 0x73726586 )
	ROM_LOAD( "hangly.6h",    0x2000, 0x1000, 0x4e7ef99f )
	ROM_LOAD( "hangly.6j",    0x3000, 0x1000, 0x7f4147e6 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( hangly2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "hangly.6e",    0x0000, 0x1000, 0x5fe8610a )
	ROM_LOAD( "hangly2.6f",   0x1000, 0x0800, 0x5ba228bb )
	ROM_LOAD( "hangly2.6m",   0x1800, 0x0800, 0xbaf5461e )
	ROM_LOAD( "hangly.6h",    0x2000, 0x1000, 0x4e7ef99f )
	ROM_LOAD( "hangly2.6j",   0x3000, 0x0800, 0x51305374 )
	ROM_LOAD( "hangly2.6p",   0x3800, 0x0800, 0x427c9d4d )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacmanh.5e",   0x0000, 0x1000, 0x299fb17a )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( puckman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "puckman.6e",   0x0000, 0x1000, 0xa8ae23c5 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "puckman.6h",   0x2000, 0x1000, 0x197443f8 )
	ROM_LOAD( "puckman.6j",   0x3000, 0x1000, 0x2e64a3ba )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( pacheart )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )     /* 64k for code */
	ROM_LOAD( "pacheart.pg1", 0x0000, 0x0800, 0xd844b679 )
	ROM_LOAD( "pacheart.pg2", 0x0800, 0x0800, 0xb9152a38 )
	ROM_LOAD( "pacheart.pg3", 0x1000, 0x0800, 0x7d177853 )
	ROM_LOAD( "pacheart.pg4", 0x1800, 0x0800, 0x842d6574 )
	ROM_LOAD( "pacheart.pg5", 0x2000, 0x0800, 0x9045a44c )
	ROM_LOAD( "pacheart.pg6", 0x2800, 0x0800, 0x888f3c3e )
	ROM_LOAD( "pacheart.pg7", 0x3000, 0x0800, 0xf5265c10 )
	ROM_LOAD( "pacheart.pg8", 0x3800, 0x0800, 0x1a21a381 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacheart.ch1", 0x0000, 0x0800, 0xc62bbabf )
	ROM_LOAD( "chg2",         0x0800, 0x0800, 0x3591b89d )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacheart.ch3", 0x0000, 0x0800, 0xca8c184c )
	ROM_LOAD( "pacheart.ch4", 0x0800, 0x0800, 0x1b1d9096 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )  /* timing - not used */
ROM_END

ROM_START( piranha )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "pr1.cpu",      0x0000, 0x1000, 0xbc5ad024 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pr3.cpu",      0x2000, 0x1000, 0x473c379d )
	ROM_LOAD( "pr4.cpu",      0x3000, 0x1000, 0x63fbf895 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pr5.cpu",      0x0000, 0x0800, 0x3fc4030c )
	ROM_LOAD( "pr7.cpu",      0x0800, 0x0800, 0x30b9a010 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pr6.cpu",      0x0000, 0x0800, 0xf3e9c9d5 )
	ROM_LOAD( "pr8.cpu",      0x0800, 0x0800, 0x133d720d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( pacplus )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "pacplus.6e",   0x0000, 0x1000, 0xd611ef68 )
	ROM_LOAD( "pacplus.6f",   0x1000, 0x1000, 0xc7207556 )
	ROM_LOAD( "pacplus.6h",   0x2000, 0x1000, 0xae379430 )
	ROM_LOAD( "pacplus.6j",   0x3000, 0x1000, 0x5a6dff7b )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5e",   0x0000, 0x1000, 0x022c35da )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5f",   0x0000, 0x1000, 0x4de65cdd )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "pacplus.7f",   0x0000, 0x0020, 0x063dd53a )
	ROM_LOAD( "pacplus.4a",   0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( mspacman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( mspacatk )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0x0af09d31 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5",   0x8000, 0x1000, 0xe6e06954 )
	ROM_LOAD( "mspacatk.6",   0x9000, 0x1000, 0x3b5db308 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( pacgal )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "pacman.7fh",   0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "pacman.7hj",   0x3000, 0x1000, 0x70694c8e )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5ef",   0x0000, 0x0800, 0x65a3ee71 )
	ROM_LOAD( "pacman.5hj",   0x0800, 0x0800, 0x50c7477d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s129.4a",    0x0020, 0x0100, 0x63efb927 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( crush )
	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for opcode copy to hack protection */
	ROM_LOAD( "crushkrl.6e",  0x0000, 0x1000, 0xa8dd8f54 )
	ROM_LOAD( "crushkrl.6f",  0x1000, 0x1000, 0x91387299 )
	ROM_LOAD( "crushkrl.6h",  0x2000, 0x1000, 0xd4455f27 )
	ROM_LOAD( "crushkrl.6j",  0x3000, 0x1000, 0xd59fc251 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "maketrax.5e",  0x0000, 0x1000, 0x91bad2da )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "maketrax.5f",  0x0000, 0x1000, 0xaea79f55 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "crush.4a",     0x0020, 0x0100, 0x2bc5d339 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( crush2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "tp1",          0x0000, 0x0800, 0xf276592e )
	ROM_LOAD( "tp5a",         0x0800, 0x0800, 0x3d302abe )
	ROM_LOAD( "tp2",          0x1000, 0x0800, 0x25f42e70 )
	ROM_LOAD( "tp6",          0x1800, 0x0800, 0x98279cbe )
	ROM_LOAD( "tp3",          0x2000, 0x0800, 0x8377b4cb )
	ROM_LOAD( "tp7",          0x2800, 0x0800, 0xd8e76c8c )
	ROM_LOAD( "tp4",          0x3000, 0x0800, 0x90b28fa3 )
	ROM_LOAD( "tp8",          0x3800, 0x0800, 0x10854e1b )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "tpa",          0x0000, 0x0800, 0xc7617198 )
	ROM_LOAD( "tpc",          0x0800, 0x0800, 0xe129d76a )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "tpb",          0x0000, 0x0800, 0xd1899f05 )
	ROM_LOAD( "tpd",          0x0800, 0x0800, 0xd35d1caf )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "crush.4a",     0x0020, 0x0100, 0x2bc5d339 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( crush3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "unkmol.4e",    0x0000, 0x0800, 0x49150ddf )
	ROM_LOAD( "unkmol.6e",    0x0800, 0x0800, 0x21f47e17 )
	ROM_LOAD( "unkmol.4f",    0x1000, 0x0800, 0x9b6dd592 )
	ROM_LOAD( "unkmol.6f",    0x1800, 0x0800, 0x755c1452 )
	ROM_LOAD( "unkmol.4h",    0x2000, 0x0800, 0xed30a312 )
	ROM_LOAD( "unkmol.6h",    0x2800, 0x0800, 0xfe4bb0eb )
	ROM_LOAD( "unkmol.4j",    0x3000, 0x0800, 0x072b91c9 )
	ROM_LOAD( "unkmol.6j",    0x3800, 0x0800, 0x66fba07d )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "unkmol.5e",    0x0000, 0x0800, 0x338880a0 )
	ROM_LOAD( "unkmol.5h",    0x0800, 0x0800, 0x4ce9c81f )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "unkmol.5f",    0x0000, 0x0800, 0x752e3780 )
	ROM_LOAD( "unkmol.5j",    0x0800, 0x0800, 0x6e00d2ac )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "crush.4a",     0x0020, 0x0100, 0x2bc5d339 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( maketrax )
	ROM_REGION( 2*0x10000, REGION_CPU1, 0 )	/* 64k for code + 64k for opcode copy to hack protection */
	ROM_LOAD( "maketrax.6e",  0x0000, 0x1000, 0x0150fb4a )
	ROM_LOAD( "maketrax.6f",  0x1000, 0x1000, 0x77531691 )
	ROM_LOAD( "maketrax.6h",  0x2000, 0x1000, 0xa2cdc51e )
	ROM_LOAD( "maketrax.6j",  0x3000, 0x1000, 0x0b4b5e0a )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "maketrax.5e",  0x0000, 0x1000, 0x91bad2da )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "maketrax.5f",  0x0000, 0x1000, 0xaea79f55 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "crush.4a",     0x0020, 0x0100, 0x2bc5d339 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( mbrush )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "mbrush.6e",    0x0000, 0x1000, 0x750fbff7 )
	ROM_LOAD( "mbrush.6f",    0x1000, 0x1000, 0x27eb4299 )
	ROM_LOAD( "mbrush.6h",    0x2000, 0x1000, 0xd297108e )
	ROM_LOAD( "mbrush.6j",    0x3000, 0x1000, 0x6fd719d0 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "tpa",          0x0000, 0x0800, 0xc7617198 )
	ROM_LOAD( "mbrush.5h",    0x0800, 0x0800, 0xc15b6967 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "mbrush.5f",    0x0000, 0x0800, 0xd5bc5cb8 )  /* copyright sign was removed */
	ROM_LOAD( "tpd",          0x0800, 0x0800, 0xd35d1caf )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "crush.4a",     0x0020, 0x0100, 0x2bc5d339 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( paintrlr )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "paintrlr.1",   0x0000, 0x0800, 0x556d20b5 )
	ROM_LOAD( "paintrlr.5",   0x0800, 0x0800, 0x4598a965 )
	ROM_LOAD( "paintrlr.2",   0x1000, 0x0800, 0x2da29c81 )
	ROM_LOAD( "paintrlr.6",   0x1800, 0x0800, 0x1f561c54 )
	ROM_LOAD( "paintrlr.3",   0x2000, 0x0800, 0xe695b785 )
	ROM_LOAD( "paintrlr.7",   0x2800, 0x0800, 0x00e6eec0 )
	ROM_LOAD( "paintrlr.4",   0x3000, 0x0800, 0x0fd5884b )
	ROM_LOAD( "paintrlr.8",   0x3800, 0x0800, 0x4900114a )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "tpa",          0x0000, 0x0800, 0xc7617198 )
	ROM_LOAD( "mbrush.5h",    0x0800, 0x0800, 0xc15b6967 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "mbrush.5f",    0x0000, 0x0800, 0xd5bc5cb8 )  /* copyright sign was removed */
	ROM_LOAD( "tpd",          0x0800, 0x0800, 0xd35d1caf )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "crush.4a",     0x0020, 0x0100, 0x2bc5d339 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( ponpoko )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "ppokoj1.bin",  0x0000, 0x1000, 0xffa3c004 )
	ROM_LOAD( "ppokoj2.bin",  0x1000, 0x1000, 0x4a496866 )
	ROM_LOAD( "ppokoj3.bin",  0x2000, 0x1000, 0x17da6ca3 )
	ROM_LOAD( "ppokoj4.bin",  0x3000, 0x1000, 0x9d39a565 )
	ROM_LOAD( "ppoko5.bin",   0x8000, 0x1000, 0x54ca3d7d )
	ROM_LOAD( "ppoko6.bin",   0x9000, 0x1000, 0x3055c7e0 )
	ROM_LOAD( "ppoko7.bin",   0xa000, 0x1000, 0x3cbe47ca )
	ROM_LOAD( "ppokoj8.bin",  0xb000, 0x1000, 0x04b63fc6 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "ppoko9.bin",   0x0000, 0x1000, 0xb73e1a06 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "ppoko10.bin",  0x0000, 0x1000, 0x62069b5d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( ponpokov )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "ppoko1.bin",   0x0000, 0x1000, 0x49077667 )
	ROM_LOAD( "ppoko2.bin",   0x1000, 0x1000, 0x5101781a )
	ROM_LOAD( "ppoko3.bin",   0x2000, 0x1000, 0xd790ed22 )
	ROM_LOAD( "ppoko4.bin",   0x3000, 0x1000, 0x4e449069 )
	ROM_LOAD( "ppoko5.bin",   0x8000, 0x1000, 0x54ca3d7d )
	ROM_LOAD( "ppoko6.bin",   0x9000, 0x1000, 0x3055c7e0 )
	ROM_LOAD( "ppoko7.bin",   0xa000, 0x1000, 0x3cbe47ca )
	ROM_LOAD( "ppoko8.bin",   0xb000, 0x1000, 0xb39be27d )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "ppoko9.bin",   0x0000, 0x1000, 0xb73e1a06 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "ppoko10.bin",  0x0000, 0x1000, 0x62069b5d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( eyes )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "d7",           0x0000, 0x1000, 0x3b09ac89 )
	ROM_LOAD( "e7",           0x1000, 0x1000, 0x97096855 )
	ROM_LOAD( "f7",           0x2000, 0x1000, 0x731e294e )
	ROM_LOAD( "h7",           0x3000, 0x1000, 0x22f7a719 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "d5",           0x0000, 0x1000, 0xd6af0030 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "e5",           0x0000, 0x1000, 0xa42b5201 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s129.4a",    0x0020, 0x0100, 0xd8d78829 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( eyes2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "g38201.7d",    0x0000, 0x1000, 0x2cda7185 )
	ROM_LOAD( "g38202.7e",    0x1000, 0x1000, 0xb9fe4f59 )
	ROM_LOAD( "g38203.7f",    0x2000, 0x1000, 0xd618ba66 )
	ROM_LOAD( "g38204.7h",    0x3000, 0x1000, 0xcf038276 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "g38205.5d",    0x0000, 0x1000, 0x03b1b4c7 )  /* this one has a (c) sign */

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "e5",           0x0000, 0x1000, 0xa42b5201 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s129.4a",    0x0020, 0x0100, 0xd8d78829 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( mrtnt )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "tnt.1",        0x0000, 0x1000, 0x0e836586 )
	ROM_LOAD( "tnt.2",        0x1000, 0x1000, 0x779c4c5b )
	ROM_LOAD( "tnt.3",        0x2000, 0x1000, 0xad6fc688 )
	ROM_LOAD( "tnt.4",        0x3000, 0x1000, 0xd77557b3 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "tnt.5",        0x0000, 0x1000, 0x3038cc0e )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "tnt.6",        0x0000, 0x1000, 0x97634d8b )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "mrtnt08.bin",  0x0000, 0x0020, 0x00000000 )
	ROM_LOAD( "mrtnt04.bin",  0x0020, 0x0100, 0x00000000 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m"  ,  0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( lizwiz )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "6e.cpu",       0x0000, 0x1000, 0x32bc1990 )
	ROM_LOAD( "6f.cpu",       0x1000, 0x1000, 0xef24b414 )
	ROM_LOAD( "6h.cpu",       0x2000, 0x1000, 0x30bed83d )
	ROM_LOAD( "6j.cpu",       0x3000, 0x1000, 0xdd09baeb )
	ROM_LOAD( "wiza",         0x8000, 0x1000, 0xf6dea3a6 )
	ROM_LOAD( "wizb",         0x9000, 0x1000, 0xf27fb5a8 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "5e.cpu",       0x0000, 0x1000, 0x45059e73 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "5f.cpu",       0x0000, 0x1000, 0xd2469717 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "7f.cpu",       0x0000, 0x0020, 0x7549a947 )
	ROM_LOAD( "4a.cpu",       0x0020, 0x0100, 0x5fdca536 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m"  ,  0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( theglob )
	ROM_REGION( 0x20000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "glob.u2",      0x0000, 0x2000, 0x829d0bea )
	ROM_LOAD( "glob.u3",      0x2000, 0x2000, 0x31de6628 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "glob.5e",      0x0000, 0x1000, 0x53688260 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "glob.5f",      0x0000, 0x1000, 0x051f59c7 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "glob.7f",      0x0000, 0x0020, 0x1f617527 )
	ROM_LOAD( "glob.4a",      0x0020, 0x0100, 0x28faa769 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m"  ,  0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( beastf )
	ROM_REGION( 0x20000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "bf-u2.bin",    0x0000, 0x2000, 0x3afc517b )
	ROM_LOAD( "bf-u3.bin",    0x2000, 0x2000, 0x8dbd76d0 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "beastf.5e",    0x0000, 0x1000, 0x5654dc34 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "beastf.5f",    0x0000, 0x1000, 0x1b30ca61 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "glob.7f",      0x0000, 0x0020, 0x1f617527 )
	ROM_LOAD( "glob.4a",      0x0020, 0x0100, 0x28faa769 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m"  ,  0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( vanvan )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "van1.bin",	  0x0000, 0x1000, 0x00f48295 )
	ROM_LOAD( "van-2.51",     0x1000, 0x1000, 0xdf58e1cb )
	ROM_LOAD( "van-3.52",     0x2000, 0x1000, 0x15571e24 )
	ROM_LOAD( "van4.bin",     0x3000, 0x1000, 0xf8b37ed5 )
	ROM_LOAD( "van5.bin",     0x8000, 0x1000, 0xb8c1e089 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "van-20.18",    0x0000, 0x1000, 0x60efbe66 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "van-21.19",    0x0000, 0x1000, 0x5dd53723 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "6331-1.6",     0x0000, 0x0020, 0xce1d9503 )
	ROM_LOAD( "6301-1.37",    0x0020, 0x0100, 0x4b803d9f )
ROM_END

ROM_START( vanvans )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "van-1.50",     0x0000, 0x1000, 0xcf1b2df0 )
	ROM_LOAD( "van-2.51",     0x1000, 0x1000, 0xdf58e1cb )
	ROM_LOAD( "van-3.52",     0x2000, 0x1000, 0x15571e24 )
	ROM_LOAD( "van-4.53",     0x3000, 0x1000, 0xb724cbe0 )
	ROM_LOAD( "van-5.39",     0x8000, 0x1000, 0xdb67414c )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "van-20.18",    0x0000, 0x1000, 0x60efbe66 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "van-21.19",    0x0000, 0x1000, 0x5dd53723 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "6331-1.6",     0x0000, 0x0020, 0xce1d9503 )
	ROM_LOAD( "6301-1.37",    0x0020, 0x0100, 0x4b803d9f )
ROM_END

ROM_START( dremshpr )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "red_1.50",	  0x0000, 0x1000, 0x830c6361 )
	ROM_LOAD( "red_2.51",     0x1000, 0x1000, 0xd22551cc )
	ROM_LOAD( "red_3.52",     0x2000, 0x1000, 0x0713a34a )
	ROM_LOAD( "red_4.53",     0x3000, 0x1000, 0xf38bcaaa )
	ROM_LOAD( "red_5.39",     0x8000, 0x1000, 0x6a382267 )
	ROM_LOAD( "red_6.40",     0x9000, 0x1000, 0x4cf8b121 )
	ROM_LOAD( "red_7.41",     0xa000, 0x1000, 0xbd4fc4ba )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "red-20.18",    0x0000, 0x1000, 0x2d6698dc )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "red-21.19",    0x0000, 0x1000, 0x38c9ce9b )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "6331-1.6",     0x0000, 0x0020, 0xce1d9503 )
	ROM_LOAD( "6301-1.37",    0x0020, 0x0100, 0x39d6fb5c )
ROM_END

ROM_START( alibaba )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "6e",           0x0000, 0x1000, 0x38d701aa )
	ROM_LOAD( "6f",           0x1000, 0x1000, 0x3d0e35f3 )
	ROM_LOAD( "6h",           0x2000, 0x1000, 0x823bee89 )
	ROM_LOAD( "6k",           0x3000, 0x1000, 0x474d032f )
	ROM_LOAD( "6l",           0x8000, 0x1000, 0x5ab315c1 )
	ROM_LOAD( "6m",           0xa000, 0x0800, 0x438d0357 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x0800, 0x85bcb8f8 )
	ROM_LOAD( "5h",           0x0800, 0x0800, 0x38e50862 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x0800, 0xb5715c86 )
	ROM_LOAD( "5k",           0x0800, 0x0800, 0x713086b3 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "alibaba.7f",   0x0000, 0x0020, 0x00000000 )  /* missing */
	ROM_LOAD( "alibaba.4a",   0x0020, 0x0100, 0x00000000 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( jumpshot )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "6e",           0x0000, 0x1000, 0xf00def9a )
	ROM_LOAD( "6f",           0x1000, 0x1000, 0xf70deae2 )
	ROM_LOAD( "6h",           0x2000, 0x1000, 0x894d6f68 )
	ROM_LOAD( "6j",           0x3000, 0x1000, 0xf15a108a )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xd9fa90f5 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x2ec711c1 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "prom.7f",      0x0000, 0x0020, 0x872b42f3 )
	ROM_LOAD( "prom.4a",      0x0020, 0x0100, 0x0399f39f )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( shootbul )
	ROM_REGION( 0x10000, REGION_CPU1, 0 ) /* 64k for code */
	ROM_LOAD( "sb6e.cpu",     0x0000, 0x1000, 0x25daa5e9 )
	ROM_LOAD( "sb6f.cpu",     0x1000, 0x1000, 0x92144044 )
	ROM_LOAD( "sb6h.cpu",     0x2000, 0x1000, 0x43b7f99d )
	ROM_LOAD( "sb6j.cpu",     0x3000, 0x1000, 0xbc4d3bbf )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "sb5e.cpu",     0x0000, 0x1000, 0x07c6c5aa )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "sb5f.cpu",     0x0000, 0x1000, 0xeaec6837 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "7f.rom",       0x0000, 0x0020, 0xec578b98 )
	ROM_LOAD( "4a.rom",       0x0020, 0x0100, 0x81a6b30f )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 ) /* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 ) /* timing - not used */
ROM_END

// Start Emu Plus
/* PacMAME Games */
ROM_START( mschamp )
	ROM_REGION( 0x12000, REGION_CPU1, 0 )
	ROM_LOAD( "pm4.bin", 0x0000, 0x10000, 0x7d6b6303 )

	ROM_REGION( 0x2000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pm1.bin", 0x0000, 0x0800, 0x8398a483 )
	ROM_LOAD( "pm3.bin", 0x1000, 0x0800, 0x08155abd )

	ROM_REGION( 0x2000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pm2.bin", 0x0000, 0x0800, 0x8398a483 )
	ROM_LOAD( "pm5.bin", 0x1000, 0x0800, 0x08155abd )

	ROM_REGION( 0x120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( superabc )
	ROM_REGION( 0x80000, REGION_CPU1, 0 )
	ROM_LOAD( "u14.rom",   0x0000, 0x80000, 0xa560efe6 )

	ROM_REGION( 0x80000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "u1.rom",   0x0000, 0x80000, 0x45caace0 )

/*
	ROM_LOAD( "u18.rom",   0x0020, 0x0100, 0x3eb3a8e4 )
*/
	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "7f.rom",    0x0000, 0x0020, 0x3a188666 )
	ROM_LOAD( "4a.rom",    0x0020, 0x0100, 0x4382c049 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( multi14 )
	ROM_REGION( 0x80000, REGION_CPU1, 0 )
	ROM_LOAD( "Mpac1_4.bin",   0x0000, 0x80000, 0x23de184d )

	ROM_REGION( 0x2000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "menuclay.gfx",   0x0000, 0x2000, 0x04a1167e )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( multi15 )
	ROM_REGION( 0x80000, REGION_CPU1, 0 )
	ROM_LOAD( "mpexe15.bin",   0x0000, 0x80000, 0xeb181a29 )

	ROM_REGION( 0x20000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "mpgfx15.bin",   0x0000, 0x20000, 0x012fb9ec )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( hanglyb )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "01",           0x0000, 0x0800, 0x9d027c4a )
	ROM_LOAD( "05",           0x0800, 0x0800, 0x194c7189 )
	ROM_LOAD( "02",           0x1000, 0x0800, 0x5ba228bb )
	ROM_LOAD( "06",           0x1800, 0x0800, 0x70810ccf )
	ROM_LOAD( "03",           0x2000, 0x0800, 0x08419c4a )
	ROM_LOAD( "07",           0x2800, 0x0800, 0x3f250c58 )
	ROM_LOAD( "04",           0x3000, 0x0800, 0x603b70b7 )
	ROM_LOAD( "08",           0x3800, 0x0800, 0x71293b1f )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "09",           0x0000, 0x0800, 0xc62bbabf )
	ROM_LOAD( "11",           0x0800, 0x0800, 0x777c70d3 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "10",         0x0000, 0x0800, 0xca8c184c )
	ROM_LOAD( "12",           0x0800, 0x0800, 0x7dc75a81 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( udpacman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2, ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( sueworld )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x677adea7 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x6c975345 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x2c809842 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacjr1 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xfcfb21a3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x9f3c32d4 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xc2310808 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( pacjr2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xcc26c905 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x9f3c32d4 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xc2310808 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( pacjr3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xd4d8cb9b )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x9f3c32d4 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xc2310808 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( pacjr4 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x42ca024b )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x9f3c32d4 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xc2310808 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( zolaslow )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0x2b9e9433 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x694450a3 )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xb5b30242 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x092292f1 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x52209eee )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( caterpil )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "puckman.6e",   0x0000, 0x1000, 0xb53c5650 )
	ROM_LOAD( "puckman.6f",   0x1000, 0x1000, 0x53845efb )
	ROM_LOAD( "puckman.6h",   0x2000, 0x1000, 0xa474357e )
	ROM_LOAD( "puckman.6j",   0x3000, 0x1000, 0x5df0ea3b )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5e",    0x0000, 0x1000, 0x0387907d )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5f",    0x0000, 0x1000, 0xaa450714 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacmulti )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacmulti.6e",    0x0000, 0x1000, 0xcfb721a8 )
	ROM_LOAD( "pacmulti.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacmulti.6h",    0x2000, 0x1000, 0xe55d5230 )
	ROM_LOAD( "pacmulti.6j",    0x3000, 0x1000, 0x29ba4b53 )
	ROM_LOAD( "pacmulti.8",     0x8000, 0x1000, 0x5a4b59dc )
	ROM_LOAD( "pacmulti.9",     0x9000, 0x1000, 0x3b939b12 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacmulti.5e",    0x0000, 0x1000, 0x46cdda4a )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacmulti.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacstrm )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x720dc3ee )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0xb2940b89 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x5c65865f )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mshangly )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( chtmsatk )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0x0af09d31 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5",   0x8000, 0x1000, 0xe6e06954 )
	ROM_LOAD( "mspacatk.6",   0x9000, 0x1000, 0x3b5db308 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( fstmsatk )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0xa8d6c227 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5",   0x8000, 0x1000, 0xe6e06954 )
	ROM_LOAD( "mspacatk.6",   0x9000, 0x1000, 0x3b5db308 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( zolamaze )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( zolatunl )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0x2b9e9433 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0c8631d1 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x694450a3 )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xb5b30242 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x52209eee )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( ultra2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x83da903e )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msatk2ad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "mspacatk.1",   0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0x0af09d31 )
	ROM_LOAD( "mspacatk.3",   0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "mspacatk.4",   0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5",   0x8000, 0x1000, 0x5a72a7a6 )
	ROM_LOAD( "mspacatk.6",   0x9000, 0x1000, 0xbd0c3e94 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xdc70ed2e )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x643d5523 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msatkad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0x0af09d31 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5",   0x8000, 0x1000, 0xe6e06954 )
	ROM_LOAD( "mspacatk.6",   0x9000, 0x1000, 0x3b5db308 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xdc70ed2e )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x643d5523 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( zolaad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )

	ROM_LOAD( "1.bin",   0x0000, 0x4000, 0x1aa2f312 )
	ROM_LOAD( "2.bin",   0x8000, 0x2000, 0x420ff603 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xdc70ed2e )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x643d5523 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( zolavect )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )

	ROM_LOAD( "1.bin",   0x0000, 0x4000, 0x1aa2f312 )
	ROM_LOAD( "2.bin",   0x8000, 0x2000, 0x420ff603 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x56560aef )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x57cb31e3 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( zolaatk )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0x2b9e9433 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0c8631d1 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x694450a3 )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xb5b30242 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x24cb5d9b )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xe0c03b4e )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( hanglyad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "hangly.6e",    0x0000, 0x1000, 0x5fe8610a )
	ROM_LOAD( "hangly.6f",    0x1000, 0x1000, 0x73726586 )
	ROM_LOAD( "hangly.6h",    0x2000, 0x1000, 0x4e7ef99f )
	ROM_LOAD( "hangly.6j",    0x3000, 0x1000, 0x7f4147e6 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x93fd3682 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xc2310808 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( vhangly )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	
	ROM_LOAD( "hangly.6e",    0x0000, 0x1000, 0x5fe8610a )
	ROM_LOAD( "hangly.6f",    0x1000, 0x1000, 0x73726586 )
	ROM_LOAD( "hangly.6h",    0x2000, 0x1000, 0x4e7ef99f )
	ROM_LOAD( "hangly.6j",    0x3000, 0x1000, 0x7f4147e6 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x022d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	
ROM_END

ROM_START( xensad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x64a10b6c )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x315f7131 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x157a6c0f )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vectxens )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x64a10b6c )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x022d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( punleash )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xeddb20e7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x57fe8b4d )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x94c63bb1 )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xfe7734d5 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xef155ffb )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x70d15899 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x713a4ba4 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x98d3d364 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x357c2523 )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x5ff3b85a )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( fpnleash )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xeddb20e7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x57fe8b4d )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x94c63bb1 )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xfe7734d5 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xef155ffb )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x70d15899 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "flat.5e",           0x0000, 0x1000, 0x1f69d1d0 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x98d3d364 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x357c2523 )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x5ff3b85a )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( sumelton )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xc1fe2c7d )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x10894f38 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xdebef8a9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacweird )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman6.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman6.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman6.6h",    0x2000, 0x1000, 0xaee79ea1 )
	ROM_LOAD( "pacman6.6j",    0x3000, 0x1000, 0x581ae70b )
	ROM_LOAD( "pacmaps.rom",   0x8000, 0x1000, 0x92fac825 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5e",    0x0000, 0x1000, 0x11077f3e )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5f",    0x0000, 0x1000, 0x7c213ab4 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msnes6m2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xe21c81ff )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xb8f8edda )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x5d7888bc )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x3abb116b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x6a4db98d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msnes6m3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xe21c81ff )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x20833779 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xa047e68f )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x3abb116b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x6a4db98d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msnes6m4 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xe21c81ff )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x23c0db46 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xdaafdb39 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x22e5b64e )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x6a4db98d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msnes4a )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xe21c81ff )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xd16b9605 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xe6b58707 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x22e5b64e )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x6a4db98d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacmn6m2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman6.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman6.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman6.6h",    0x2000, 0x1000, 0xaee79ea1 )
	ROM_LOAD( "pacman6.6j",    0x3000, 0x1000, 0x581ae70b )
	ROM_LOAD( "pacmaps.rom",   0x8000, 0x1000, 0xaadee235 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5e",    0x0000, 0x1000, 0x60ada878 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msmini )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x7787a3f6 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x98ab3c44 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( msminia )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0x0af09d31 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5",   0x8000, 0x1000, 0xe6e06954 )
	ROM_LOAD( "mspacatk.6",   0x9000, 0x1000, 0x3b5db308 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x7787a3f6 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x98ab3c44 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( mspc6mad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xe21c81ff )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xb556fe78 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x4dbe1939 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x92ea9860 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x713cc17e )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( msvctr6m )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )	/* 64k for code */
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xe21c81ff )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xd0bd89d9 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xc5662407 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x64b35a5a )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x57cb31e3 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )	/* sound PROMs */
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )	/* timing - not used */
ROM_END

ROM_START( pmad6m )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman6.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman6.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman6.6h",    0x2000, 0x1000, 0xaee79ea1 )
	ROM_LOAD( "pacman6.6j",    0x3000, 0x1000, 0x581ae70b )
	ROM_LOAD( "pacmaps.rom",   0x8000, 0x1000, 0xd6a0d7f2 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5e",    0x0000, 0x1000, 0x93fd3682 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5f",    0x0000, 0x1000, 0xc2310808 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( snakeyes )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman6.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman6.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman6.6h",    0x2000, 0x1000, 0xaee79ea1 )
	ROM_LOAD( "pacman6.6j",    0x3000, 0x1000, 0x581ae70b )
	ROM_LOAD( "pacmaps.rom",   0x8000, 0x1000, 0x7e506e78 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5e",    0x0000, 0x1000, 0x46cdda4a )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( tbone )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman6.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman6.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman6.6h",    0x2000, 0x1000, 0xaee79ea1 )
	ROM_LOAD( "pacman6.6j",    0x3000, 0x1000, 0x581ae70b )
	ROM_LOAD( "pacmaps.rom",   0x8000, 0x1000, 0xe7377f2d )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5e",    0x0000, 0x1000, 0xafd44c48 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vectr6m )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman6.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman6.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman6.6h",    0x2000, 0x1000, 0xaee79ea1 )
	ROM_LOAD( "pacman6.6j",    0x3000, 0x1000, 0x581ae70b )
	ROM_LOAD( "pacmaps.rom",   0x8000, 0x1000, 0xde753fd9 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5e",    0x0000, 0x1000, 0xf7be09ba )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vectr6tb )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman6.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman6.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman6.6h",    0x2000, 0x1000, 0xaee79ea1 )
	ROM_LOAD( "pacman6.6j",    0x3000, 0x1000, 0x581ae70b )
	ROM_LOAD( "pacmaps.rom",   0x8000, 0x1000, 0xbdbbb207 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5e",    0x0000, 0x1000, 0xf7be09ba )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( snowpac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x4f9e1d02 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x2cc60a94 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x41ba87bd )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msultra )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x36b5e9fd )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xcf609615 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x7cd365 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x508af5b0 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0xdb5a4630 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msnes63 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xf4ea7d2c )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x1ea43bba )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xd3a28769 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x6a4db98d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msnes62 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x52120bc9 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x8fd36e02 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xd3a28769 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x6a4db98d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msnes6m )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xe21c81ff )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xbc091971 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x23ebe9a1 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x3abb116b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x6a4db98d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( ms2600 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xc2a293df )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x4852db05 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xf32b076f )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x6b07b97a )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0xf844608b )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mspacren )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xefe80423 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xf513ae17 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xce3b842b )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x31b134a0 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x22f61d1 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x7b6aa3c9 )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x64fe1dbf )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( baby2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x260b87b8 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x6f7d8d57 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xb6d77a1e )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( baby3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x6c0e22c8 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x22174b65 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xb6d77a1e )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( baby4 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xf8cd7ebb )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x22174b65 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xb6d77a1e )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msbaby )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x17aea21d )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xc08aa7f )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xe28aaa1f )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xe764738d )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x3d316ad0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msbaby1 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x17aea21d )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xc08aa7f )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xe28aaa1f )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xe764738d )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x3d316ad0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacman6 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman6.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman6.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman6.6h",    0x2000, 0x1000, 0xaee79ea1 )
	ROM_LOAD( "pacman6.6j",    0x3000, 0x1000, 0x581ae70b )
	ROM_LOAD( "pacmaps.rom",   0x8000, 0x1000, 0xde753fd9 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5e",    0x0000, 0x1000, 0x46cdda4a )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( ultrapac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman6.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman6.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman6.6h",    0x2000, 0x1000, 0xaee79ea1 )
	ROM_LOAD( "pacman6.6j",    0x3000, 0x1000, 0x84c6c23b )
	ROM_LOAD( "pacmaps.rom",   0x8000, 0x1000, 0xbe212894 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5e",    0x0000, 0x1000, 0xd46efbcf )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman6.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( crazypac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x9f754a51 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( dizzy )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xbf05bf15 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0xf999a8d9 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x7cb7b9b1 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msrumble )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x15b02313 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0xe2473a86 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x17abb097 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mrpacman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x65c0526c )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x4078d9b2 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0xc1637f1c )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x83e6a3a9 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x45dadf0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vcrunchy )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xc21c6c52 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacbell )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x4b428215 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacelec )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x9e5c763d )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacjail )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xcc31f185 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacshuf )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x55cc4d87 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpspeed )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xe7946d1 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacms1 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xc5da3887 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x35f0597 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x306b24f0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacms2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xb0a107ea )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x35f0597 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x306b24f0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacms3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xc7d8325a )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x35f0597 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x306b24f0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacms4 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x7b63ff9b )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x35f0597 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x306b24f0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacmsa1 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x7163b97 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x35f0597 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x306b24f0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacmsa2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x15e83c24 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x35f0597 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x306b24f0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacmsa3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x5762f9cf )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x35f0597 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x306b24f0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vpacmsa4 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xd9c2a669 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x35f0597 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x306b24f0 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vecbaby )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "babypac.6j",    0x3000, 0x1000, 0x4e4ac798 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vecbaby2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "babypac2.6j",    0x3000, 0x1000, 0x742453ba )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vecbaby3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "babypac3.6j",    0x3000, 0x1000, 0xb82f2b73 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( puckren )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xf5ecf67 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x70ea1149 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xc6bb6ea6 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xdc90f1dc )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0xa502e25f )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x18d44098 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x7b6aa3c9 )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x64fe1dbf )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( puckrenc )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xf5ecf67 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x8a75a7e2 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xc6bb6ea6 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xdc90f1dc )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0xa502e25f )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x18d44098 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x7b6aa3c9 )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x64fe1dbf )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mspacatb )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0x0af09d31 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5b",   0x8000, 0x1000, 0x5a72a7a6 )
	ROM_LOAD( "mspacatk.6b",   0x9000, 0x1000, 0x7a8c4dfe )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mspacii )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "msp2p36e.bin",    0x0000, 0x1000, 0xdf673b57 )
	ROM_LOAD( "msp2p46f.bin",    0x1000, 0x1000, 0x7591f606 )
	ROM_LOAD( "msp2p56h.bin",    0x2000, 0x1000, 0xc8ef1a7f )
	ROM_LOAD( "msp2p66j.bin",    0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "msp2p7s1.bin",    0x8000, 0x1000, 0xfbbc3d2e )
	ROM_LOAD( "msp2p8s2.bin",    0x9000, 0x1000, 0xaba3096d )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "msp2p15e.bin",    0x0000, 0x1000, 0x4333722 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "msp2p25f.bin",    0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( zolapac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )

	ROM_LOAD( "1.bin",   0x0000, 0x4000, 0x1aa2f312 )
	ROM_LOAD( "2.bin",   0x8000, 0x2000, 0x420ff603 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacms1 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xc5da3887 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x7394868b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xce1a3264 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacms2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xb0a107ea )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x7394868b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xce1a3264 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacms3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xc7d8325a )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x7394868b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xce1a3264 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacms4 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x7b63ff9b )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x7394868b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xce1a3264 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacmsa1 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x7163b97 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x7394868b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xce1a3264 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacmsa2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x15e83c24 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x7394868b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xce1a3264 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacmsa3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x5762f9cf )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x7394868b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xce1a3264 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacmsa4 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xd9c2a669 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x7394868b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xce1a3264 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( fastplus )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
/*	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0x0af09d31 ) */
	ROM_LOAD( "boot2",   	  0x1000, 0x1000, 0xa8d6c227 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5",   0x8000, 0x1000, 0xe6e06954 )
	ROM_LOAD( "mspacatk.6",   0x9000, 0x1000, 0x3b5db308 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacbaby )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "babypac.6j",    0x3000, 0x1000, 0x4e4ac798 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacbaby2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "babypac2.6j",  0x3000, 0x1000, 0x742453ba )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacbaby3 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "babypac3.6j",    0x3000, 0x1000, 0xb82f2b73 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( plusfast )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacplus.6e",   0x0000, 0x1000, 0xd611ef68 )
	ROM_LOAD( "pacplus.6f",   0x1000, 0x1000, 0xc7207556 )
	ROM_LOAD( "pacplus.6h",   0x2000, 0x1000, 0xae379430 )
	ROM_LOAD( "pacplus.6j",   0x3000, 0x1000, 0x5a6dff7b )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5e",    0x0000, 0x1000, 0x22c35da )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5f",    0x0000, 0x1000, 0x4de65cdd )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "pacplus.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "pacplus.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pmanaltm )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xfee263b3 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0xc5ec2352 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0x2083b03 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x57a07f6e )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( faststrm )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xa8d6c227 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xb2940b89 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x5c65865f )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mshearts )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xb5cf081 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vectplus )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacplus.6e",   0x0000, 0x1000, 0xd611ef68 )
	ROM_LOAD( "pacplus.6f",   0x1000, 0x1000, 0xc7207556 )
	ROM_LOAD( "pacplus.6h",   0x2000, 0x1000, 0xae379430 )
	ROM_LOAD( "pacplus.6j",   0x3000, 0x1000, 0x5a6dff7b )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5e",    0x0000, 0x1000, 0x330abcc6 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5f",    0x0000, 0x1000, 0x61da12cf )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "pacplus.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "pacplus.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacbell )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x4b428215 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacelec )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x9e5c763d )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacinvis )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x1b4e96dc )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacjail )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xcc31f185 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacshuf )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x55cc4d87 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacspeed )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xe7946d1 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pcrunchy )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xc21c6c52 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacm255 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xd3640977 )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacn255 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "namcopac.6e",  0x0000, 0x1000, 0xfee263b3 )
	ROM_LOAD( "namcopac.6f",  0x1000, 0x1000, 0x39d1fc83 )
	ROM_LOAD( "namcopac.6h",  0x2000, 0x1000, 0x6dac9e8f )
	ROM_LOAD( "namcopac.6j",  0x3000, 0x1000, 0x7a36fe55 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( hearts )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x5be0a4e4 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacplusc )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacplusc.rom",   0x0000, 0x4000, 0xa0d25591 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5e",    0x0000, 0x1000, 0x22c35da )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5f",    0x0000, 0x1000, 0x4de65cdd )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "pacplus.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "pacplus.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pmad00 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xdd2eb43d )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x5f1aea94 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x315f7131 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x157a6c0f )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msf1pac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0xe255428b )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xc7183fd2 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0xa355e061 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( eltonpac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x9c093e5b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xc2825641 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( xensrev )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x64a10b6c )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x40e3522d )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pengman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x37e7f3ba )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x2f5f5e6 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x5cd3db2e )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( europac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xa4e82007 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x208da4 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xd36dabf )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pac2600 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x0a27d11d )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xab23fe0c )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x87d8f5ce )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x91bd671f )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( roboman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xa909673e )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0xe386213e )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xd8db5788 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pmad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xdd2eb43d )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0xff3f4866 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x5b794d59 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x59a9362c )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pmada )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xdd2eb43d )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x24e43519 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x9f3c32d4 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xc2310808 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacmini )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x5e04f9c5 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x5520b393 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x30e6024c )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacmini2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x092dd5fa )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x130eff7b )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x30e6024c )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pacman3d )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x96364259 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x959e930e )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0xaa203d45 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xd1830540 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vectrpac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x936d0475 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x22d0686 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( brakman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x1a6fb2d4 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x2d2af2e5 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0xa004abe7 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x30ed6264 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( fastpac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x720dc3ee )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( chtpac )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x72cea888 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( fastpop )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x720dc3ee )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xaf2b610b )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( chtpop )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacman.6e",    0x0000, 0x1000, 0xc1e6ab10 )
	ROM_LOAD( "pacman.6f",    0x1000, 0x1000, 0x72cea888 )
	ROM_LOAD( "pacman.6h",    0x2000, 0x1000, 0xbcdd1beb )
	ROM_LOAD( "pacman.6j",    0x3000, 0x1000, 0x817d94e3 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacman.5f",    0x0000, 0x1000, 0xaf2b610b )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pmanalt )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "namcopac.6e",    0x0000, 0x1000, 0xfee263b3 )
	ROM_LOAD( "namcopac.6f",    0x1000, 0x1000, 0xc5ec2352 )
	ROM_LOAD( "namcopac.6h",    0x2000, 0x1000, 0x02083b03 )
	ROM_LOAD( "namcopac.6j",    0x3000, 0x1000, 0x57a07f6e )
/*
	ROM_REGION_DISPOSE(0x2000)
	ROM_LOAD( "namcopac.5e",    0x0000, 0x1000, 0x0c944964 )
	ROM_LOAD( "namcopac.5f",    0x1000, 0x1000, 0x958fedf9 )
*/
	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "namcopac.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "namcopac.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( fasthang )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "hangly.6e",    0x0000, 0x1000, 0x5fe8610a )
	ROM_LOAD( "hangly.6f",    0x1000, 0x1000, 0x1b1014bc )
	ROM_LOAD( "hangly.6h",    0x2000, 0x1000, 0x4e7ef99f )
	ROM_LOAD( "hangly.6j",    0x3000, 0x1000, 0x7f4147e6 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "hangly.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "hangly.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( chthang )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "hangly.6e",    0x0000, 0x1000, 0x5fe8610a )
	ROM_LOAD( "hangly.6f",    0x1000, 0x1000, 0x73726586 )
	ROM_LOAD( "hangly.6h",    0x2000, 0x1000, 0x4e7ef99f )
	ROM_LOAD( "hangly.6j",    0x3000, 0x1000, 0x7f4147e6 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "hangly.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "hangly.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mazeman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "puckman.6e",   0x0000, 0x1000, 0xa8ae23c5 )
	ROM_LOAD( "puckman.6f",   0x1000, 0x1000, 0x77e44852 )
	ROM_LOAD( "puckman.6h",   0x2000, 0x1000, 0x6d16a528 )
	ROM_LOAD( "puckman.6j",   0x3000, 0x1000, 0x3c3ff208 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5e",    0x0000, 0x1000, 0x38870a32 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5f",    0x0000, 0x1000, 0x1fd18b80 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( fastpuck )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "puckman.6e",   0x0000, 0x1000, 0xa8ae23c5 )
	ROM_LOAD( "puckman.6f",   0x1000, 0x1000, 0x720dc3ee )
	ROM_LOAD( "puckman.6h",   0x2000, 0x1000, 0x197443f8 )
	ROM_LOAD( "puckman.6j",   0x3000, 0x1000, 0x2e64a3ba )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( chtpuck )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "puckman.6e",   0x0000, 0x1000, 0xa8ae23c5 )
	ROM_LOAD( "puckman.6f",   0x1000, 0x1000, 0x72cea888 )
	ROM_LOAD( "puckman.6h",   0x2000, 0x1000, 0x197443f8 )
	ROM_LOAD( "puckman.6j",   0x3000, 0x1000, 0x2e64a3ba )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( puckman2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "puckman.6e",   0x0000, 0x1000, 0xa8ae23c5 )
	ROM_LOAD( "puckman.6f",   0x1000, 0x1000, 0x720dc3ee )
	ROM_LOAD( "puckman.6h",   0x2000, 0x1000, 0x197443f8 )
	ROM_LOAD( "puckman.6j",   0x3000, 0x1000, 0x0e3bdbde )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( fstpman2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "puckman.6e",   0x0000, 0x1000, 0xa8ae23c5 )
	ROM_LOAD( "puckman.6f",   0x1000, 0x1000, 0x720dc3ee )
	ROM_LOAD( "puckman.6h",   0x2000, 0x1000, 0x197443f8 )
	ROM_LOAD( "puckman.6j",   0x3000, 0x1000, 0x0e3bdbde )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( chtpman2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "puckman.6e",   0x0000, 0x1000, 0xa8ae23c5 )
	ROM_LOAD( "puckman.6f",   0x1000, 0x1000, 0x72cea888 )
	ROM_LOAD( "puckman.6h",   0x2000, 0x1000, 0x197443f8 )
	ROM_LOAD( "puckman.6j",   0x3000, 0x1000, 0x0e3bdbde )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5e",    0x0000, 0x1000, 0x0c944964 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "puckman.5f",    0x0000, 0x1000, 0x958fedf9 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( pplusad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "pacplus.6e",   0x0000, 0x1000, 0xd611ef68 )
	ROM_LOAD( "pacplus.6f",   0x1000, 0x1000, 0xc7207556 )
	ROM_LOAD( "pacplus.6h",   0x2000, 0x1000, 0xae379430 )
	ROM_LOAD( "pacplus.6j",   0x3000, 0x1000, 0x5a6dff7b )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5e",    0x0000, 0x1000, 0xce684d85 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "pacplus.5f",    0x0000, 0x1000, 0xb86d002 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "pacplus.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "pacplus.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mssilad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x79d241dd )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x2e2fcde0 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x22c6d19a )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xdc70ed2e )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x643d5523 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mspac6m )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "1.cpu",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "2.cpu",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "3.cpu",        0x2000, 0x1000, 0x513f4d5c )
	ROM_LOAD( "4.cpu",        0x3000, 0x1000, 0xe21c81ff )
	ROM_LOAD( "52.cpu",       0x8000, 0x1000, 0xd0bd89d9 )
	ROM_LOAD( "62.cpu",       0x9000, 0x1000, 0xc5662407 )

	ROM_REGION( 0x2000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "7.cpu",           0x0000, 0x0800, 0x2850148a )
	ROM_LOAD( "9.cpu",           0x0800, 0x0800, 0x6c3c6ebb )

	ROM_REGION( 0x2000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "8.cpu",           0x0000, 0x0800, 0x5596b345 )
	ROM_LOAD( "10.cpu",          0x0800, 0x0800, 0x50c7477d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "pacplus.7f",    0x0000, 0x0020, 0x63dd53a )
	ROM_LOAD( "pacplus.4a",    0x0020, 0x0100, 0xe271a166 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mspacad )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xc3dca510 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x57cb31e3 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END


ROM_START( msberzk )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x795b1d20 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x9fc2a679 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x6749a32d )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x92692429 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x7c32ed2e )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msdstorm )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xd32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xb2940b89 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x5c65865f )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msindy )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x8e234b3a )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0xc7183fd2 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0xa355e061 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mspacrip )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x5fb1ee61 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5aa9eb83 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0xceb3785d )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msyakman )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x827892bb )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x1108ba96 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( msvectr )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x56560aef )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x57cb31e3 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mselton )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x30d0b19f )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( fasthear )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xa8d6c227 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x28eb876c )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x50fc9966 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( heartbrn )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0d32de5e )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x28eb876c )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x50fc9966 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( fastmspa )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0xa8d6c227 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( chtmspa )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot2",        0x1000, 0x1000, 0x0af09d31 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "boot5",        0x8000, 0x1000, 0x8c3e6de6 )
	ROM_LOAD( "boot6",        0x9000, 0x1000, 0x368cb165 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( mspacat2 )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "mspacatk.1",   0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0x0af09d31 )
	ROM_LOAD( "mspacatk.3",   0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "mspacatk.4",   0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5",   0x8000, 0x1000, 0x5a72a7a6 )
	ROM_LOAD( "mspacatk.6",   0x9000, 0x1000, 0xbd0c3e94 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x5c281d01 )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x615af909 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

ROM_START( vectratk )
	ROM_REGION( 0x10000, REGION_CPU1, 0 )
	ROM_LOAD( "mspacatk.1",   0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "mspacatk.2",   0x1000, 0x1000, 0x0af09d31 )
	ROM_LOAD( "mspacatk.3",   0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "mspacatk.4",   0x3000, 0x1000, 0x165a9dd8 )
	ROM_LOAD( "mspacatk.5",   0x8000, 0x1000, 0xe6e06954 )
	ROM_LOAD( "mspacatk.6",   0x9000, 0x1000, 0x3b5db308 )
	ROM_LOAD( "boot1",        0x0000, 0x1000, 0xd16b31b7 )
	ROM_LOAD( "boot3",        0x2000, 0x1000, 0x1821ee0b )
	ROM_LOAD( "boot4",        0x3000, 0x1000, 0x165a9dd8 )

	ROM_REGION( 0x1000, REGION_GFX1 , ROMREGION_DISPOSE )
	ROM_LOAD( "5e",           0x0000, 0x1000, 0x56560aef )

	ROM_REGION( 0x1000, REGION_GFX2 , ROMREGION_DISPOSE )
	ROM_LOAD( "5f",           0x0000, 0x1000, 0x57cb31e3 )

	ROM_REGION( 0x0120, REGION_PROMS, 0 )
	ROM_LOAD( "82s123.7f",    0x0000, 0x0020, 0x2fc650bd )
	ROM_LOAD( "82s126.4a",    0x0020, 0x0100, 0x3eb3a8e4 )

	ROM_REGION( 0x0200, REGION_SOUND1, 0 )
	ROM_LOAD( "82s126.1m",    0x0000, 0x0100, 0xa9cc86bf )
	ROM_LOAD( "82s126.3m",    0x0100, 0x0100, 0x77245b66 )
ROM_END

/* End PacMAME */
// End Emu Plus

static READ_HANDLER( maketrax_special_port2_r )
{
	int pc,data;

	pc = cpu_getpreviouspc();

	data = input_port_2_r(offset);

	if ((pc == 0x1973) || (pc == 0x2389)) return data | 0x40;

	switch (offset)
	{
		case 0x01:
		case 0x04:
			data |= 0x40; break;
		case 0x05:
			data |= 0xc0; break;
		default:
			data &= 0x3f; break;
	}

	return data;
}

static READ_HANDLER( maketrax_special_port3_r )
{
	int pc;

	pc = cpu_getpreviouspc();

	if ( pc == 0x040e) return 0x20;

	if ((pc == 0x115e) || (pc == 0x3ae2)) return 0x00;

	switch (offset)
	{
		case 0x00:
			return 0x1f;
		case 0x09:
			return 0x30;
		case 0x0c:
			return 0x00;
		default:
			return 0x20;
	}
}

static void maketrax_rom_decode(void)
{
	unsigned char *rom = memory_region(REGION_CPU1);
	int diff = memory_region_length(REGION_CPU1) / 2;


	/* patch protection using a copy of the opcodes so ROM checksum */
	/* tests will not fail */
	memory_set_opcode_base(0,rom+diff);

	memcpy(rom+diff,rom,diff);

	rom[0x0415 + diff] = 0xc9;
	rom[0x1978 + diff] = 0x18;
	rom[0x238e + diff] = 0xc9;
	rom[0x3ae5 + diff] = 0xe6;
	rom[0x3ae7 + diff] = 0x00;
	rom[0x3ae8 + diff] = 0xc9;
	rom[0x3aed + diff] = 0x86;
	rom[0x3aee + diff] = 0xc0;
	rom[0x3aef + diff] = 0xb0;
}

static void init_maketrax(void)
{
	/* set up protection handlers */
	install_mem_read_handler(0, 0x5080, 0x50bf, maketrax_special_port2_r);
	install_mem_read_handler(0, 0x50c0, 0x50ff, maketrax_special_port3_r);

	maketrax_rom_decode();
}

static void init_ponpoko(void)
{
	int i, j;
	unsigned char *RAM, temp;

	/* The gfx data is swapped wrt the other Pac-Man hardware games. */
	/* Here we revert it to the usual format. */

	/* Characters */
	RAM = memory_region(REGION_GFX1);
	for (i = 0;i < memory_region_length(REGION_GFX1);i += 0x10)
	{
		for (j = 0; j < 8; j++)
		{
			temp          = RAM[i+j+0x08];
			RAM[i+j+0x08] = RAM[i+j+0x00];
			RAM[i+j+0x00] = temp;
		}
	}

	/* Sprites */
	RAM = memory_region(REGION_GFX2);
	for (i = 0;i < memory_region_length(REGION_GFX2);i += 0x20)
	{
		for (j = 0; j < 8; j++)
		{
			temp          = RAM[i+j+0x18];
			RAM[i+j+0x18] = RAM[i+j+0x10];
			RAM[i+j+0x10] = RAM[i+j+0x08];
			RAM[i+j+0x08] = RAM[i+j+0x00];
			RAM[i+j+0x00] = temp;
		}
	}
}

static void eyes_decode(unsigned char *data)
{
	int j;
	unsigned char swapbuffer[8];

	for (j = 0; j < 8; j++)
	{
		swapbuffer[j] = data[(j >> 2) + (j & 2) + ((j & 1) << 2)];
	}

	for (j = 0; j < 8; j++)
	{
		char ch = swapbuffer[j];

		data[j] = (ch & 0x80) | ((ch & 0x10) << 2) |
					 (ch & 0x20) | ((ch & 0x40) >> 2) | (ch & 0x0f);
	}
}

static void init_eyes(void)
{
	int i;
	unsigned char *RAM;

	/* CPU ROMs */

	/* Data lines D3 and D5 swapped */
	RAM = memory_region(REGION_CPU1);
	for (i = 0; i < 0x4000; i++)
	{
		RAM[i] =  (RAM[i] & 0xc0) | ((RAM[i] & 0x08) << 2) |
				  (RAM[i] & 0x10) | ((RAM[i] & 0x20) >> 2) | (RAM[i] & 0x07);
	}


	/* Graphics ROMs */

	/* Data lines D4 and D6 and address lines A0 and A2 are swapped */
	RAM = memory_region(REGION_GFX1);
	for (i = 0;i < memory_region_length(REGION_GFX1);i += 8)
		eyes_decode(&RAM[i]);
	RAM = memory_region(REGION_GFX2);
	for (i = 0;i < memory_region_length(REGION_GFX2);i += 8)
		eyes_decode(&RAM[i]);
}


static void init_pacplus(void)
{
	pacplus_decode();
}

static void init_jumpshot(void)
{
	jumpshot_decode();
}

static void init_shootbul(void)
{
	shootbul_decode();
}



/*          rom       parent    machine   inp       init */
GAME( 1980, pacman,   0,        pacman,   pacman,   0,        ROT90,  "Namco", "PuckMan (Japan set 1)" )
GAME( 1980, pacmanjp, pacman,   pacman,   pacman,   0,        ROT90,  "Namco", "PuckMan (Japan set 2)" )
GAME( 1980, pacmanm,  pacman,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man (Midway)" )
GAME( 1981, npacmod,  pacman,   pacman,   pacman,   0,        ROT90,  "Namco", "PuckMan (harder?)" )
GAME( 1981, pacmod,   pacman,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man (Midway, harder)" )
GAME( 1981, hangly,   pacman,   pacman,   pacman,   0,        ROT90,  "hack", "Hangly-Man (set 1)" )
GAME( 1981, hangly2,  pacman,   pacman,   pacman,   0,        ROT90,  "hack", "Hangly-Man (set 2)" )
GAME( 1980, puckman,  pacman,   pacman,   pacman,   0,        ROT90,  "hack", "New Puck-X" )
GAME( 1981, pacheart, pacman,   pacman,   pacman,   0,        ROT90,  "hack", "Pac-Man (Hearts)" )
GAME( 1981, piranha,  pacman,   pacman,   mspacman, 0,        ROT90,  "hack", "Piranha" )
GAME( 1982, pacplus,  0,        pacman,   pacman,   pacplus,  ROT90,  "[Namco] (Midway license)", "Pac-Man Plus" )
GAME( 1981, mspacman, 0,        pacman,   mspacman, 0,        ROT90,  "bootleg", "Ms. Pac-Man" )
GAME( 1981, mspacatk, mspacman, pacman,   mspacman, 0,        ROT90,  "hack", "Ms. Pac-Man Plus" )
GAME( 1981, pacgal,   mspacman, pacman,   mspacman, 0,        ROT90,  "hack", "Pac-Gal" )
GAME( 1981, crush,    0,        pacman,   maketrax, maketrax, ROT90,  "Kural Samno Electric", "Crush Roller (Kural Samno)" )
GAME( 1981, crush2,   crush,    pacman,   maketrax, 0,        ROT90,  "Kural Esco Electric", "Crush Roller (Kural Esco - bootleg?)" )
GAME( 1981, crush3,   crush,    pacman,   maketrax, eyes,     ROT90,  "Kural Electric", "Crush Roller (Kural - bootleg?)" )
GAME( 1981, maketrax, crush,    pacman,   maketrax, maketrax, ROT270, "[Kural] (Williams license)", "Make Trax" )
GAME( 1981, mbrush,   crush,    pacman,   mbrush,   0,        ROT90,  "bootleg", "Magic Brush" )
GAME( 1981, paintrlr, crush,    pacman,   paintrlr, 0,        ROT90,  "bootleg", "Paint Roller" )
GAME( 1982, ponpoko,  0,        pacman,   ponpoko,  ponpoko,  ROT0,   "Sigma Ent. Inc.", "Ponpoko" )
GAME( 1982, ponpokov, ponpoko,  pacman,   ponpoko,  ponpoko,  ROT0,   "Sigma Ent. Inc. (Venture Line license)", "Ponpoko (Venture Line)" )
GAME( 1982, eyes,     0,        pacman,   eyes,     eyes,     ROT90,  "Digitrex Techstar (Rock-ola license)", "Eyes (Digitrex Techstar)" )
GAME( 1982, eyes2,    eyes,     pacman,   eyes,     eyes,     ROT90,  "Techstar Inc. (Rock-ola license)", "Eyes (Techstar Inc.)" )
GAME( 1983, mrtnt,    0,        pacman,   mrtnt,    eyes,     ROT90,  "Telko", "Mr. TNT" )
GAME( 1985, lizwiz,   0,        pacman,   lizwiz,   0,        ROT90,  "Techstar (Sunn license)", "Lizard Wizard" )
GAME( 1983, theglob,  0,        theglob,  theglob,  0,        ROT90,  "Epos Corporation", "The Glob" )
GAME( 1984, beastf,   theglob,  theglob,  theglob,  0,        ROT90,  "Epos Corporation", "Beastie Feastie" )
GAME( 1982, dremshpr, 0,        dremshpr, dremshpr, 0,        ROT270, "Sanritsu", "Dream Shopper" )
GAME( 1983, vanvan,   0,        vanvan,   vanvan,   0,        ROT270, "Karateco", "Van Van Car" )
GAME( 1983, vanvans,  vanvan,   vanvan,   vanvans,  0,        ROT270, "Sanritsu", "Van Van Car (Sanritsu)" )
GAME( 1982, alibaba,  0,        alibaba,  alibaba,  0,        ROT90,  "Sega", "Ali Baba and 40 Thieves" )
GAME( 1985, jumpshot, 0,        pacman,   jumpshot, jumpshot, ROT90,  "Bally Midway", "Jump Shot" )
GAME( 1985, shootbul, 0,        pacman,   shootbul, shootbul, ROT90,  "Bally Midway", "Shoot the Bull" )
// Start Emu Plus
// NOTE!!! I have made all games stand alone (i.e. they do NOT have a parent set.)
// I did this so that they will NOT mess up your valid mame sets. PacMAME site gives
// you a nice warning about this (don't mix and match your mame/pacmame sets)
// This should allow stuff like clrmamepro (awesome btw) to work with no hitches. May
// possibly require you to build some of these sets by hand. Maybe some site will post
// these as full pacmame sets. I dunno.. if you have to rebuild em by hand Boo Hoo get over it :)

/* PacMAME Drivers */
/* I have added the parent of each set to each game, this is needed for my PacTray frontend */
/* and the automatic update feature to work. Once a new PacMAME is released, PacTray will issue */
/* the 'pacmame -listclones > list.dat' and rebuild the pacmame.lst file from this. The pacmame.lst */
/* file contains the 'name,rom name, screenshot, cabinet, flyer, hi score format' list. */
/* The name & rom name are pretty straight forward, the others are based off of the parent set */
/* name, for example, pacbell is a clone of pacman, therefore the parent is pacman, so, when */
/* PacTray rebuilds the pacmame.lst file the entry for pacbell will look like this */

/* Pacman (The Bell),pacbell,pacbell.png,pacman.png,pacman.png,pacman */
/*                                           ^-----------^--------^------- from parent name */
/* Make sense ? I hope. */
/* I know other emus remove this (ie EmuPlus, which kicks ass BTW), but if there is another way */
/* to accomplish what I need, then I can change it */
/* I've updated FRONTHLP.C so that the -listfull display will include the 'clone of' display */

// Pacmame is quite cool also. Thanks :) Nope have to make them each a parent set because it conflicts with 
// the rest of mame and I don't want someone having the roms get deleted and then complaining to me about it. 
// Maybe we can add a field for the hi and png files? I'll shoot you an email or you shoot me one if you see this
// cuz I would like to take a shot at adding those artwork overlays in if you want/need a hand still. 
// /rant And also thanks for actually releasing source code and COMMENTING your changes. It
// makes things so much easier for people. I like what mamelang32 has done but I really wish he would comment his
// code and release ACTUAL source code and not some lousy diff file. /rantdone
/*    Year  Name      Parent    Machine  Input     Init	     Monitor Company    Full Name */
GAME( 2000, udpacman, 0,   pacman,   pacman,   0,        ROT90,  "PacMAME", "Upside-Down Pacman" )
GAME( 1981, hanglyb,  0,   pacman,   pacman,   0,        ROT90,  "hack", "Hangly-Man (Hearts)" ) 
GAME( 2000, baby2,    0,   pacman,   pacman,   0,        ROT90,  "T-Bone", "Baby Pacman 2 (Alt)" )
GAME( 2000, baby3,    0,   pacman,   pacman,   0,        ROT90,  "T-Bone", "Baby Pacman 3 (Alt)" )
GAME( 2000, baby4,    0,   pacman,   pacman,   0,        ROT90,  "T-Bone", "Pacman (Baby Maze 4)" )
GAME( 2000, brakman,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Brakman" )
GAME( 2000, caterpil, 0,   pacman,   pacman,   0,        ROT90,  "Phi", "Caterpillar" )
GAME( 2000, chthang,  0,   fastpac,  pacman,   0,        ROT90,  "[Namco] (Midway license)", "Hangly Man (Cheat)" )
GAME( 2000, chtmsatk, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man Plus (Cheat)" )
GAME( 2000, chtmspa,  0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man (Cheat)" )
GAME( 2000, chtpac,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man (Cheat)" )
GAME( 2000, chtpman2, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Puck-Man II (Cheat)" )
GAME( 2000, chtpop,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man / Popeye (Cheat)" )
GAME( 2000, chtpuck,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Puck-Man (Cheat)" )
GAME( 2000, crazypac, 0,   pacman,   pacman,   0,        ROT90,  "Tim Appleton a.k.a. medragon", "Crazy Pac" )
GAME( 2000, dizzy,    0,   pacman,   pacman,   0,        ROT90,  "Tim Appleton a.k.a. medragon", "Dizzy Ghost - A Reversal of Roles" )
GAME( 2000, eltonpac, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Elton Pac" )
GAME( 2000, europac,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Euro Pac" )
GAME( 2000, fasthang, 0,   fastpac,  pacman,   0,        ROT90,  "[Namco] (Midway license)", "Hangly Man (Fast)" )
GAME( 2000, fasthear, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Heart Burn (Fast)" )
GAME( 2000, fastmspa, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man (Fast)" )
GAME( 2000, fastpac,  0,   fastpac,  pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man (Fast)" )
GAME( 2000, fastplus, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man Plus (Fast)" )
GAME( 2000, fastpop,  0,   fastpac,  pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man / Popeye (Fast)" )
GAME( 2000, fastpuck, 0,   fastpac,  pacman,   0,        ROT90,  "[Namco] (Midway license)", "Puck-Man (Fast)" )
GAME( 2000, faststrm, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Desert Storm (Fast)" )
GAME( 2000, fpnleash, 0,   pacman,   mspacman, 0,        ROT90,  "Peter Storey", "Pacman Unleashed (Flat)" )
GAME( 2000, fstmsatk, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man Attack (Fast)" )
GAME( 2000, fstpman2, 0,   fastpac,  pacman,   0,        ROT90,  "[Namco] (Midway license)", "Puck-Man II (Fast)" )
GAME( 2000, hanglyad, 0,   pacman,   pacman,   0,        ROT90,  "hack", "Hangly-Man (set 1) After Dark" )
GAME( 2000, heartbrn, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Heart Burn" )
GAME( 2000, hearts,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Hearts Bootleg)" )
GAME( 2000, mazeman,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Maze Man" )
GAME( 2000, mrpacman, 0,   pacman,   mspacman, 0,        ROT90,  "Tim Appleton a.k.a. medragon", "Mr. Pac-Man - Another Kind of Role Reversal" )
GAME( 2000, ms2600,   0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman 2600" )
GAME( 2000, msatk2ad, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man Plus / Attack After Dark" )
GAME( 2000, msatkad,  0,   pacman,   mspacman, 0,        ROT90,  "hack", "Ms. Pac-Man Plus After Dark" )
GAME( 2000, msbaby,   0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Baby Pacman" )
GAME( 2000, msbaby1,  0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Baby Pacman (Alt)" )
GAME( 2000, msberzk,  0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man Berzerk" )
GAME( 2000, msdstorm, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Desert Storm" )
GAME( 2000, mselton,  0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Elton" )
GAME( 2000, msf1pac,  0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. F1 Pac-Man" )
GAME( 2000, mshangly, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Hangly Man" )
GAME( 2000, mshearts, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man Hearts" )
GAME( 2000, msindy,   0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Indy" )
GAME( 2000, msmini,   0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pac-Mini" )
GAME( 2000, msminia,  0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pac-Attack Mini" )
GAME( 2000, msnes4a,  0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman SNES (Tall Alternate)" )
GAME( 2000, msnes62,  0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman NES (Set 2)" )
GAME( 2000, msnes63,  0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman NES (Set 3)" )
GAME( 2000, msnes6m,  0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman NES" )
GAME( 2000, msnes6m2, 0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman SNES (New Mazes)" )
GAME( 2000, msnes6m3, 0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman SNES (Regular / Tall" )
GAME( 2000, msnes6m4, 0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman SNES (Regular)" )
GAME( 2000, mspac6m,  0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man 6M (Six Maze)" )
GAME( 2000, mspacad,  0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man After Dark" )
GAME( 2000, mspacat2, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man Plus / Attack" )
GAME( 2000, mspacatb, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man Plus (Set B)" )
GAME( 2000, mspacii,  0,   zolapac,  mspacman, 0,	     ROT90,  "PacMAME", "Ms. Pac-Man II (Orca)" )
GAME( 2000, mspacren, 0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman Renaissance" )
GAME( 2000, mspacrip, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Mortem" )
GAME( 2000, mspc6mad, 0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Ms. Pacman After Dark (6 Mazes)" )
GAME( 2000, msrumble, 0,   pacman,   mspacman, 0,        ROT90,  "Tim Appleton a.k.a. medragon", "Ms. Pac Rumble" )
GAME( 2000, mssilad,  0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pac-Man After Dark (Sil)" )
GAME( 2000, msultra,  0,   pacman,   mspacman, 0,        ROT90,  "PacFan", "Ms. Ultra Pacman" )
GAME( 2000, msvctr6m, 0,   pacman,   mspacman, 0,        ROT90,  "T-Bone", "Vector Ms. Pacman (6 Mazes)" )
GAME( 2000, msvectr,  0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Vector Ms. Pac-Man" )
GAME( 2000, msyakman, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Yak Man" )
GAME( 2000, pac2600,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac 2600" )
GAME( 2000, pacbaby,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Baby Maze 1)" )
GAME( 2000, pacbaby2, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Baby Maze 2)" )
GAME( 2000, pacbaby3, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Baby Maze 3)" )
GAME( 2000, pacbell,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Bell)" )
GAME( 2000, pacelec,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Electric Cownboy)" )
GAME( 2000, pacinvis, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Original Inviso)" )
GAME( 2000, pacjail,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Jail)" )
GAME( 2000, pacjr1,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman Jr. (Maze 1)" )
GAME( 2000, pacjr2,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman Jr. (Maze 2)" )
GAME( 2000, pacjr3,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman Jr. (Maze 3)" )
GAME( 2000, pacjr4,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman Jr. (Maze 4)" )
GAME( 2000, pacm255,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man (Midway 255th Maze)" )
GAME( 2000, pacman3d, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man 3D" )
GAME( 2000, pacman6,  0,   pacman,   mspacman, 0,        ROT90,  "Sil", "Pacman 6" )
GAME( 2000, pacmini,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Mini Pac-Man" )
GAME( 2000, pacmini2, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Mini Pac-Man 2" )
GAME( 2000, pacmn6m2, 0,   pacman,   pacman,   0,        ROT90,  "Sil", "Pacman 2000 (Set 2)" )
GAME( 2000, pacms1,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Ms. Pacman Maze 1)" )
GAME( 2000, pacms2,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Ms. Pacman Maze 2)" )
GAME( 2000, pacms3,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Ms. Pacman Maze 3)" )
GAME( 2000, pacms4,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Ms. Pacman Maze 4)" )
GAME( 2000, pacmsa1,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Ms. Pacman Attack 1)" )
GAME( 2000, pacmsa2,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Ms. Pacman Attack 2)" )
GAME( 2000, pacmsa3,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Ms. Pacman Attack 3)" )
GAME( 2000, pacmsa4,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Ms. Pacman Attack 4)" )
GAME( 2000, pacmulti, 0,   pacman,   pacman,   0,        ROT90,  "Sil", "PacMulti (Pacman)" )
GAME( 2000, pacn255,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man (Namco 255th Maze)" )
GAME( 2000, pacplusc, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man Plus (Unencrypted)" )
GAME( 2000, pacshuf,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Shuffle)" )
GAME( 2000, pacspeed, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Speedy)" )
GAME( 2000, pacstrm,  0,   pacman,   pacman,   0,        ROT90,  "PacMAME", "Desert Storm Pac-Man" )
GAME( 2000, pacweird, 0,   pacman,   pacman,   0,        ROT90,  "Staizitto", "Pacman (Six Map Weird)" )
GAME( 2000, pcrunchy, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pacman (Crunchy)" )
GAME( 2000, pengman,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pengo Man" )
GAME( 2000, plusfast, 0,   plusfast, pacman,   pacplus,  ROT90,  "[Namco] (Midway license)", "Pac-Man Plus (Fast)" )
GAME( 2000, pmad,     0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man After Dark" )
GAME( 2000, pmad00,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man After Dark 2000" )
GAME( 2000, pmad6m,   0,   pacman,   pacman,   0,        ROT90,  "T-Bone", "Pacman 2000 After Dark" )
GAME( 2000, pmada,    0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man After Dark (Alternate)" )
GAME( 2000, pmanalt,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man Vertical Tunnels (Cheat)" )
GAME( 2000, pmanaltm, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Pac-Man (Midway Vertical Tunnels)" )
GAME( 2000, pplusad,  0,   pacman,   pacman,   pacplus,  ROT90,  "[Namco] (Midway license)", "Pac-Man Plus After Dark" )
GAME( 2000, puckman2, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Puck-Man II" )
GAME( 2000, puckren,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Puckman Renaissance" )
GAME( 2000, puckrenc, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Puckman Renaissance (Cheat)" )
GAME( 2000, punleash, 0,   pacman,   mspacman, 0,        ROT90,  "Peter Storey", "Pacman Unleashed" )
GAME( 2000, roboman,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Robo Man" )
GAME( 2000, snakeyes, 0,   pacman,   pacman,   0,        ROT90,  "T-Bone", "Pacman 2000 (Snake Eyes Mazes)")
GAME( 2000, snowpac,  0,   pacman,   pacman,   0,        ROT90,  "T-Bone", "Snowy Day Pacman" )
GAME( 2000, sueworld, 0,   pacman,   mspacman, 0,        ROT90,  "PacFay", "Sue's World" )
GAME( 2000, sumelton, 0,   pacman,   pacman,   0,        ROT90,  "Staizitto", "Summertime Elton" )
GAME( 2000, tbone,    0,   pacman,   pacman,   0,        ROT90,  "T-Bone", "Pacman 2000 (T-Bone Mazes)")
GAME( 2000, ultra2,   0,   pacman,   pacman,   0,        ROT90,  "PacMAME", "Ultra Pacman (TwoBit Score Mazes)" )
GAME( 2000, ultrapac, 0,   pacman,   pacman,   0,        ROT90,  "PacFan", "UltraPac" )
GAME( 2000, vcrunchy, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Crunchy)" )
GAME( 2000, vecbaby,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Baby Maze 1)" )
GAME( 2000, vecbaby2, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Baby Maze 2)" )
GAME( 2000, vecbaby3, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Baby Maze 3)" )
GAME( 2000, vectplus, 0,   pacman,   pacman,   pacplus,  ROT90,  "[Namco] (Midway license)", "Vector Pac-Man Plus" )
GAME( 2000, vectr6m,  0,   pacman,   pacman,   0,        ROT90,  "T-Bone", "Vector Pacman 2000")
GAME( 2000, vectr6tb, 0,   pacman,   pacman,   0,        ROT90,  "T-Bone", "Vector Pacman 2000 (T-Bone Mazes)")
GAME( 2000, vectratk, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Vector Attack" )
GAME( 2000, vectrpac, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pac-Man" )
GAME( 2000, vectxens, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Xens Revenge" )
GAME( 2000, vhangly,  0,   pacman,   pacman,   0,        ROT90,  "hack", "Vector Hangly-Man (set 1)" )
GAME( 2000, vpacbell, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Bell)" )
GAME( 2000, vpacelec, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Electric Cowboy)" )
GAME( 2000, vpacjail, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Jail)" )
GAME( 2000, vpacms1,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Ms. Pacman Maze 1)" )
GAME( 2000, vpacms2,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Ms. Pacman Maze 2)" )
GAME( 2000, vpacms3,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Ms. Pacman Maze 3)" )
GAME( 2000, vpacms4,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Ms. Pacman Maze 4)" )
GAME( 2000, vpacmsa1, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Ms. Pacman Attack 1)" )
GAME( 2000, vpacmsa2, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Ms. Pacman Attack 2)" )
GAME( 2000, vpacmsa3, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Ms. Pacman Attack 3)" )
GAME( 2000, vpacmsa4, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Ms. Pacman Attack 4)" )
GAME( 2000, vpacshuf, 0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Shuffle)" )
GAME( 2000, vpspeed,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Vector Pacman (Speedy)" )
GAME( 2000, xensad,   0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Xens Revenge After Dark" )
GAME( 2000, xensrev,  0,   pacman,   pacman,   0,        ROT90,  "[Namco] (Midway license)", "Xens Revenge" )
GAME( 2000, zolaad,   0,   zolapac,  zolapac,  0,        ROT90,  "PacMAME", "Super Zola Pac Gal After Dark" )
GAME( 2000, zolaatk,  0,   zolapac,  zolapac,  0,        ROT90,  "PacMAME", "Super Zola Pac Gal Attack" )
GAME( 2000, zolamaze, 0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "Ms. Pacman (Zola Mazes)" )
GAME( 2000, zolapac,  0,   zolapac,  zolapac,  0,        ROT90,  "PacMAME", "Super Zola Pac Gal" )
GAME( 2000, zolaslow, 0,   zolapac,  zolapac,  0,        ROT90,  "PacMAME", "Super Zola Pac Gal (Slow)" )
GAME( 2000, zolatunl, 0,   zolapac,  zolapac,  0,        ROT90,  "PacMAME", "Super Zola Pac Gal (Tunnels)" )
GAME( 2000, zolavect, 0,   zolapac,  zolapac,  0,        ROT90,  "PacMAME", "Vector Super Zola Pac Gal" )

GAME( 1998, multi14,  0,   pacman,   mspacman, 0,        ROT90,  "Clay Cowgill", "MultiPac 1.4" )
GAME( 1998, multi15,  0,   pacman,   mspacman, 0,        ROT90,  "PacMAME", "MultiPac 1.5" )
GAME( 1998, superabc, 0,   pacman,   mspacman, 0,        ROT90,  "TwoBit Score", "Super ABC Pacman" )
GAME( 2000, mschamp,  0,   zolapac,  zolapac,  0,        ROT90,  "PacMAME", "Ms. Pacman Championship Edition" )
/* End PacMAME 23 Dec 2000*/
// End Emu Plus
